package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.40.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.40.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@("`0`````````````#`!8````!````````*```````````0```````
M`+'(``````!``#@`"0!``!L`&@````8````$`````````$``````````0```
M``````!``````````?@````````!^``````````(`````P````0````````"
M.`````````(X`````````C@`````````#P`````````/``````````$````!
M````!0```````````````````````````````````````*JP````````JK``
M```````0``````$````&````````JZ@```````"[J````````+NH````````
M!.`````````%"````````!```````@````8```````"KN````````+NX````
M````N[@````````"(`````````(@``````````@````$````!`````````)(
M`````````D@````````"2`````````!$`````````$0`````````!&1TY5``
M```$````````HY````````"CD````````*.0`````````.P`````````[```
M```````$9'3E40````8`````````````````````````````````````````
M`````````````````````!!D=.52````!````````*NH````````NZ@`````
M``"[J`````````18````````!%@``````````2]L:6(O;&0V-"YS;RXQ````
M```$````$`````%'3E4```````````0````#``````````0````4`````T=.
M50#;)3"`[E?Q(%(;W>6`R[1;=?WL40``````````````0P````````!=````
M``````````````````````````!7````````````````````+P`````````P
M````````````````````4````````````````````"H`````````5```````
M```[`````````"@`````````5@````````!"`````````#$`````````/```
M````````````````````````````.```````````````````````````````
M-P`````````7`````````$X`````````*P`````````R`````````!8`````
M````40````````!/````````````````````````````````````````````
M````````*0`````````=`````````"4```````````````````!-````````
M`$P````````````````````_````````````````````/@````````!:````
M````````````````(P`````````$````````````````````20``````````
M``````````8```````````````````!9`````````#H`````````&0``````
M``!!````````````````````2`````````!5`````````!@`````````-@``
M```````+`````````$,`````````/0`````````M`````````$4`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````H``````````@``````````````````
M``4`````````2P```````````````````$8`````````$@````````!;````
M````````````````````````````````````````````````"```````````
M``````````X`````````4@`````````,``````````<`````````&P``````
M```3````````````````````#0```````````````````"0`````````````
M`````````````````%,`````````)@````````````````````D`````````
M```````````@`````````````````````````````````````````!X`````
M```````````````G``````````\`````````-0````````!*````````````
M````````,P`````````B`````````!0`````````$0`````````N````````
M`!P`````````'P````````!$````````````````````````````````````
M`````"P`````````7```````````````````````````````(0``````````
M````````````````````6``````````0````````````````````%0``````
M`````````````#D`````````0````````````````````$<`````````&@``
M```````T````````````````````````````````````````````````````
M``````````````````````,````1````0P````0````(A`1`!0`0$""$`(:`
M!``"*`@$(`D"`(F""`(`ND$0@(@`````````0P```$8```!)````2@```%(`
M``!3````5`````````!6````5P```%@```!9````6@```%P``````````!_?
MQ6XM1][.?)I_:[:;Q2Y\U&34#N3_(1Q8<=D!QD?B;XL!LL#C2ZR'U_I"+#_E
MPGR2X[I@;*'ZF\-/F=9#"6MFS*]G[-5%0M-P!XGMVV(SS"6,%0N7.@V;G*E_
M"@*GX%">&FM)^^"C```````````````````````````````````````````#
M```,````````'F```````````````V\2````````````````````````````
M`I\2`````````````````````````````(P1````````````````````````
M`````<,2`````````````````````````````@82````````````````````
M`````````H82`````````````````````````````-(2````````````````
M`````````````D(2``````````````````````````````$@````````````
M`````````````````G\2`````````````````````````````&<2````````
M`````````````````````;82`````````````````````````````-L2````
M`````````````````````````M$2`````````````````````````````842
M`````````````````````````````?82````````````````````````````
M`2D2`````````````````````````````6H2````````````````````````
M`````)02`````````````````````````````!`@````````````````````
M`````````K<2`````````````````````````````2`2````````````````
M`````````````(H1`````````````````````````````3<2````````````
M`````````````````"P@`````````````````````````````)T2````````
M`````````````````````JD2`````````````````````````````5L2````
M`````````````````````````.$6`````````````````````````````/02
M`````````````````````````````7X2````````````````````````````
M`E42`````````````````````````````0\2````````````````````````
M`````L(2`````````````````````````````+,2````````````````````
M`````````%@B`````````````````````````````=`2````````````````
M`````````````;$2`````````````````````````````3X2````````````
M`````````````````<H2`````````````````````````````6,2````````
M`````````````````````:(2`````````````````````````````I$2````
M`````````````````````````B<2`````````````````````````````'D2
M`````````````````````````````7<2````````````````````````````
M`>$2`````````````````````````````)P2````````````````````````
M`````,L2`````````````````````````````A(2````````````````````
M`````````;X2`````````````````````````````G,2````````````````
M`````````````J02`````````````````````````````>\2````````````
M`````````````````F81`````````````````````````````8P2````````
M`````````````````````*02`````````````````````````````+T2````
M`````````````````````````002`````````````````````````````4T2
M`````````````````````````````*L2````````````````````````````
M`C,2`````````````````````````````$82````````````````````````
M`````902`````````````````````````````9L1````````````````````
M`````````W@2```.````````7I``````````T````\T2```.````````55``
M```````'`@```%,2```.````````)8`````````"@````N\2```.````````
M1\``````````!@```PT2```.````````7%@````````"-@```_,2```.````
M````1\@````````":````[,0```8````````P(@``````````````P`2```.
M````````2C``````````-@```R,2```.````````45``````````@````X01
M```0````````8P``````````!````Z`2```.````````7]`````````!Z@``
M`ZL2```.````````1H@`````````.````\@0```8````````P+``````````
M`````^$2```.````````5&``````````\```!`H2```.````````4=``````
M````>````Y,0```7````````P````````````````T<2```.````````2F@`
M```````!5````]H0```8````````P(@`````````````!``1```7````````
MP(``````````"````YD2```.````````*````````````````[\2```.````
M````7V``````````;````Y4@```7````````P````````````````UT2```.
M````````5#``````````+````S$2```.````````1L``````````_@```U,2
M```.````````8<``````````_```!!(2```.````````2\`````````%C`!?
M7V=M;VY?<W1A<G1?7P!?251-7V1E<F5G:7-T97)434-L;VYE5&%B;&4`7TE4
M35]R96=I<W1E<E1-0VQO;F5486)L90!?7VQI8F-?<W1A<G1?;6%I;@!?7V-X
M85]F:6YA;&EZ90!?7W)E9VES=&5R7V%T9F]R:P!?7W-T86-K7V-H:U]F86EL
M`%]?96YV:7)O;@!S=')N8VUP`&QS=&%T-C0`86-C97-S`&]P96YD:7(`<F5A
M9&1I<C8T`%]?<W!R:6YT9E]C:&L`=6YL:6YK`&-L;W-E9&ER`')M9&ER`%!,
M7V-U<G)E;G1?8V]N=&5X=`!B;V]T7T1Y;F%,;V%D97(`4&5R;%]N97=84P!0
M97)L7VYE=UA37V9L86=S`')E861L:6YK`%!E<FQ?<W9?<V5T<'8`;65M8VAR
M`%!E<FQ?<W9?<V5T<'9N`%]?;65M;6]V95]C:&L`<F5A;&QO8P!G971P:60`
M7U]M96UC<'E?8VAK`'-T<F-H<@!S=')D=7``<W1R=&]K`'-T<G)C:'(`;65M
M8W!Y`'-T9&5R<@!?7W9F<')I;G1F7V-H:P!E>&ET`&QS965K-C0`<F5A9`!G
M971U:60`;6MD:7(`7U]E<G)N;U]L;V-A=&EO;@!?7V9P<FEN=&9?8VAK`&]P
M96XV-`!097)L7V=V7V9E=&-H<'8`4&5R;%]G971?<W8`4&5R;%]C<F]A:U]N
M;V-O;G1E>'0`4&5R;%]M9U]S970`4&5R;%]S>7-?:6YI=#,`4&5R;%]A=&9O
M<FM?=6YL;V-K`%!E<FQ?871F;W)K7VQO8VL`4$Q?9&]?=6YD=6UP`%!E<FQ?
M<V%F97-Y<VUA;&QO8P!P97)L7W!A<G-E`'!E<FQ?9&5S=')U8W0`<&5R;%]F
M<F5E`%!E<FQ?<WES7W1E<FT`<&5R;%]A;&QO8P!P97)L7V-O;G-T<G5C=`!P
M97)L7W)U;@!L:6)P97)L+G-O`&QI8F,N<V\N-@!P87)?8W5R<F5N=%]E>&5C
M`'!A<E]B87-E;F%M90!84U]);G1E<FYA;'-?4$%27T)/3U0`<&%R7V5N=E]C
M;&5A;@!P87)?8W5R<F5N=%]E>&5C7W!R;V,`<&%R7V1I<FYA;64`<VAA7V9I
M;F%L`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P`%])
M3U]S=&1I;E]U<V5D`%]?9&%T85]S=&%R=`!S:&%?=7!D871E`'AS7VEN:70`
M7U]B<W-?<W1A<G0`<VAA7VEN:70`7V5N9`!P87)?;6MT;7!D:7(`7V5D871A
M`'!A<E]S971U<%]L:6)P871H`'!A<E]F:6YD<')O9P!M>5]P87)?<&P`<&%R
M7V1I90!P87)?:6YI=%]E;G8`1TQ)0D-?,BXS-`!'3$E"0U\R+C0`1TQ)0D-?
M,BXS,P!'3$E"0U\R+C,N-`!'3$E"0U\R+C,N,@!'3$E"0U\R+C(`+W5S<B]L
M:6(O<&5R;#4O-2XT,"XP+W,S.3!X+6QI;G5X+71H<F5A9"UM=6QT:2]#3U)%
M``````````(``0`"``(``0`!``(``0`!``(``P`"``(``0`"``$``0`$``(`
M`0`!``(``@`"``$`!0`!``(``0`!``(``0`!``$``@`"``(``@`!``(``@`&
M``$``0`&``(`!@`%``(``0`"``$``@`"``$``@`"``8``0`$``(``0`'``(`
M`@`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`&```"Y0```!``````!I:1M`````<```0?````$`UI:10`
M```&```$*@```!`&EI&S````!0``!#0````0"6D9=`````0```0_````$`EI
M&7(````#```$2P```!`-:6D2`````@``!%<`````````````NZ@`````````
M#````````"D`````````N[``````````#````````"BX````````O_@`````
M````#````````"6`````````P`@`````````#````````,`(````````P"``
M````````#````````*-P````````P"@`````````#````````&-<````````
MP#@`````````#````````&/\````````P$``````````#````````&0`````
M````P$@`````````#````````*-D````````P%``````````#````````&-B
M````````P%@`````````#````````*-L````````P&@`````````#```````
M`*-4````````P'``````````#````````*-:````````P(``````````#```
M`````&7D````````OZ`````$````"@``````````````````OZ@````)````
M"@``````````````````O[`````*````"@``````````````````O[@````5
M````"@``````````````````O\`````:````"@``````````````````O\@`
M```>````.```````````````````O]`````?````"@``````````````````
MO]@````A````"@``````````````````O^`````E````"@``````````````
M````O^@````X````"@``````````````````O_````!"````"@``````````
M````````O?`````"````"P``````````````````O?@````#````"P``````
M````````````O@`````%````"P``````````````````O@@````&````"P``
M````````````````OA`````'````"P``````````````````OA@````(````
M"P``````````````````OB`````+````"P``````````````````OB@````,
M````"P``````````````````OC`````-````"P``````````````````OC@`
M```.````"P``````````````````OD`````/````"P``````````````````
MOD@````0````"P``````````````````OE`````1````"P``````````````
M````OE@````2````"P``````````````````OF`````3````"P``````````
M````````OF@````4````"P``````````````````OG`````6````"P``````
M````````````OG@````7````"P``````````````````OH`````9````"P``
M````````````````OH@````;````"P``````````````````OI`````<````
M"P``````````````````OI@````=````"P``````````````````OJ`````@
M````"P``````````````````OJ@````B````"P``````````````````OK``
M```C````"P``````````````````OK@````D````"P``````````````````
MOL`````E````"P``````````````````OL@````F````"P``````````````
M````OM`````G````"P``````````````````OM@````H````"P``````````
M````````ON`````I````"P``````````````````ON@````J````"P``````
M````````````OO`````K````"P``````````````````OO@````L````"P``
M````````````````OP`````M````"P``````````````````OP@````N````
M"P``````````````````OQ`````O````"P``````````````````OQ@````P
M````"P``````````````````OR`````Q````"P``````````````````OR@`
M```R````"P``````````````````OS`````S````"P``````````````````
MOS@````T````"P``````````````````OT`````U````"P``````````````
M````OT@````V````"P``````````````````OU`````W````"P``````````
M````````OU@````Y````"P``````````````````OV`````Z````"P``````
M````````````OV@````[````"P``````````````````OW`````\````"P``
M````````````````OW@````]````"P``````````````````OX`````^````
M"P``````````````````OX@````_````"P``````````````````OY````!`
M````"P``````````````````OY@```!!````"P``````````ZV_P,``DN00`
M'Z?[_V#C$/```"3`P```3[+`$```4)OC$!````2Y`@`1IX0``PWAXT#Q$``$
MZV_PT``$!_0``.,0\#@`),`0``!/F=('\#`0".,0$!``!`?Q!P`'``<`P!``
M`$^8XQ`0```$!_$-$.,0$`P`%,#T____Y0````#`$```3XSC$!````0'\0T0
MXQ`0#``4P/3____5````&,`0``!/@.,0$```!`?Q#1#C$!`,`!3`]/___\4`
M```PP!```$]TXQ`0```$!_$-$.,0$`P`%,#T____M0```$C`$```3VCC$!``
M``0'\0T0XQ`0#``4P/3___^E````8,`0``!/7.,0$```!`?Q#1#C$!`,`!3`
M]/___Y4```!XP!```$]0XQ`0```$!_$-$.,0$`P`%,#T____A0```)#`$```
M3T3C$!````0'\0T0XQ`0#``4P/3___]U````J,`0``!/..,0$```!`?Q#1#C
M$!`,`!3`]/___V4```#`P!```$\LXQ`0```$!_$-$.,0$`P`%,#T____50``
M`-C`$```3R#C$!````0'\0T0XQ`0#``4P/3___]%````\,`0``!/%.,0$```
M!`?Q#1#C$!`,`!3`]/___S4```$(P!```$\(XQ`0```$!_$-$.,0$`P`%,#T
M____)0```2#`$```3OSC$!````0'\0T0XQ`0#``4P/3___\5```!.,`0``!.
M\.,0$```!`?Q#1#C$!`,`!3`]/___P4```%0P!```$[DXQ`0```$!_$-$.,0
M$`P`%,#T___^]0```6C`$```3MCC$!````0'\0T0XQ`0#``4P/3___[E```!
M@,`0``!.S.,0$```!`?Q#1#C$!`,`!3`]/___M4```&8P!```$[`XQ`0```$
M!_$-$.,0$`P`%,#T___^Q0```;#`$```3K3C$!````0'\0T0XQ`0#``4P/3_
M__ZU```!R,`0``!.J.,0$```!`?Q#1#C$!`,`!3`]/___J4```'@P!```$Z<
MXQ`0```$!_$-$.,0$`P`%,#T___^E0```?C`$```3I#C$!````0'\0T0XQ`0
M#``4P/3___Z%```"$,`0``!.A.,0$```!`?Q#1#C$!`,`!3`]/___G4```(H
MP!```$YXXQ`0```$!_$-$.,0$`P`%,#T___^90```D#`$```3FSC$!````0'
M\0T0XQ`0#``4P/3___Y5```"6,`0``!.8.,0$```!`?Q#1#C$!`,`!3`]/__
M_D4```)PP!```$Y4XQ`0```$!_$-$.,0$`P`%,#T___^-0```HC`$```3DCC
M$!````0'\0T0XQ`0#``4P/3___XE```"H,`0``!./.,0$```!`?Q#1#C$!`,
M`!3`]/___A4```*XP!```$XPXQ`0```$!_$-$.,0$`P`%,#T___^!0```M#`
M$```3B3C$!````0'\0T0XQ`0#``4P/3___WU```"Z,`0``!.&.,0$```!`?Q
M#1#C$!`,`!3`]/___>4```,`P!```$X,XQ`0```$!_$-$.,0$`P`%,#T___]
MU0```QC`$```3@#C$!````0'\0T0XQ`0#``4P/3___W%```#,,`0``!-].,0
M$```!`?Q#1#C$!`,`!3`]/___;4```-(P!```$WHXQ`0```$!_$-$.,0$`P`
M%,#T___]I0```V#`$```3=SC$!````0'\0T0XQ`0#``4P/3___V5```#>,`0
M``!-T.,0$```!`?Q#1#C$!`,`!3`]/___84```.0P!```$W$XQ`0```$!_$-
M$.,0$`P`%,#T___]=0```ZC`$```3;CC$!````0'\0T0XQ`0#``4P/3___UE
M```#P,`0``!-K.,0$```!`?Q#1#C$!`,`!3`]/___54```/8P!```$V@XQ`0
M```$!_$-$.,0$`P`%,#T___]10```_#`$```393C$!````0'\0T0XQ`0#``4
MP/3___TU```$",`0``!-B.,0$```!`?Q#1#C$!`,`!3`]/___24```0@P!``
M`$U\XQ`0```$!_$-$.,0$`P`%,#T___]%0``!#C`$```37#C$!````0'\0T0
MXQ`0#``4P/3___T%```$4,`0``!-9.,0$```!`?Q#1#C$!`,`!3`]/___/4`
M``1HP!```$U8XQ`0```$!_$-$.,0$`P`%,#T___\Y0``!(#`$```34SC$!``
M``0'\0T0XQ`0#``4P/3___S5```$F,`0``!-0.,0$```!`?Q#1#C$!`,`!3`
M]/___,4```2PP!```$TTXQ`0```$!_$-$.,0$`P`%,#T___\M0``!,C`$```
M32CC$!````0'\0T0XQ`0#``4P/3___RE```$X,`0``!-'.,0$```!`?Q#1#C
M$!`,`!3`]/___)4```3XZV_P,``DX_#_./]QXS#PJ``DXT#PH``D4"#PM$%`
M\*!!,/"H02#PM+)/`+#KNP`@``VR3P"QT@?PP+`HP.7___^RQ$@``$SSQ"@`
M`$T(N00`-,#E```>=\08``!-")4`$`"GA`"VP#```$SQXU`P```$6*#PM.R:
M``0`V+D4`.GC9;````3K+@`#``V6`V2*IZH``\#E___^]N,0\*@`!,`P```?
MWN,`$```!.,P(`@`).,`(```)+D$`%+$*P``32[`0```'\_C0%`8`"3$*```
M31GC(%`0`"18D/"T[)P`Q0%^[.D``P#8[`G__P#803`0"*<H``2G`0`!IW0`
M@H@```&Y%`!"[!(``0#8Z^0``P`-N10`8>-`,```!.-.4```).L6``,`#>-@
M,`@`!.-A4```)*<J``*G.P`0IP;_X^QI``,`V+D4`):Y%`!*ZZD``P`-02I0
M`*=I``#E2"````#`,```#<K$*```3-_`Y?___"CL*`!4`'[$*```3-9!8/"\
MP.7___WMN00`-KD$`)+`(```'DW`Y0``#$?L*`!'`'S$*```3,'`Y?__^]K`
MY?___0?5!_#`L"BG=`!9N00`*>MO\/@`!`?^P.7___RYQ"L``$RJ["@`3@!\
MP.7___TPP#```$PQXR`P```$XT*P```$D@!)!J?T_SCC,#````3C,%`@`"2G
M*``%03`0$.PN_W9@=J?T_Y3$*```3(7`Y?___"ZG]/^IP%```$QYXR!0```"
MIX0`!\#E```;::?T_[&Y!``VP"```!W)P.4```OKQ"L``$QD["C_I`!\I_3_
M[:=H``2G]/]NP.7___V8IRD``<#E___](T%`\`CC,/````2G"?_PN8``\*?[
M_U#7!_``\`#K[_"@`"1!</"@IVD``*=9``#`(```2^7C("````3`Y?___H,`
M``<'!P<'!\`0``!,(,`@``!,'>P2``J`9,08``!+K^P8``0`?`?Q!_X'!P<'
M!P?`$```3`S`(```3`FY"0`2ZP$``P`*ZS$`/P`,N0@`,.LS``$`"NPX``T`
M?,08``!+DNP8``<`?,`@``!+\`?Q!_X'!P<'!P?KO_!8`"3`L```2^7C\/]@
M_W&5`+``IW0`%<`0``!+A^,0$````J>$``C$*```2Y/`Y?___(S`Y?___ZV2
M`;``Z[_P^``$!_[`]/___[@'!^MO\#``)./P_-#_<;)/`+#KNP`@``VR3P"Q
M01#PJ-('\RBP**<)``1!4"`XXT!0```$XS!0"``$ZZ0`(``,XZ`0```DZV,`
M(``,XV`0$``DP$H`````XT`0"``DP#H`````XS`0&``D05!0$*<;`""G!__>
MXS#Q$``$XX#Q&``$XZ#Q(``$XY#PJ``$XW#PL``$04#PN*<)`$"Y!`#:X^!`
M```$N00`'N,00#``@KF"`!.Y@@`9[*$@OR%5[*$@/@%6XZ!`<``DN00`.+D$
M`)>Y!`"-ITL`"*<'"MKC8"`(``3C8/"@`"3C0"`0``3C`"`8``3C4/"P``2Y
MYP"4PEI:@GF9N8``EKD(`%"Y@@"0X^`@```$ZW8``@`,[*X@OR55['8`(1Y6
M[*X@.@56[#<@OP!5XQ#PJ``$N><PU,(:6H)YF;F``-[C$"`@``BY@@#4N0@`
M&KGH4(VY"``9[)$@OP!5[%$[OR55[%D`.@56N0@`6.NN``(`#.S5.[\E5>RN
M`"$>5N,0\+@`!.R*(+\`5;GGH&?"&EJ">9GL=2"_`%6Y@`!I[-<`.@56N8(`
M8[D(`!3C4/#```2Y"``6PEI:@GF9N0@`';D(`%/K.0`"``SL.0`A'E:Y@@"C
M[)$@OP!5[&$[OR55N>1P&KD$`*;LJ0`Z!5;L8R"_`%6Y@@`8X]#PR``$N0@`
M%<+:6H)YF;D(`!JYZ(!=ZZ<``@`,[($[OR55[*<`(1Y6['$@OP!5[(<`.@56
MN8(`.N,0\-``!+F``#G"&EJ">9FY@@`VN0@`-;GH8%&Y"``X[&H@OP!5ZXD`
M`@`,[(D`(1Y6N8(`J.R3(+\`5>S3.[\E5;GD<#JY!`"M[*D`.@56N8(`-N,0
M\-@`!+D(`#7"&EJ">9FY"``ZN>A@4>NG``(`#.QH(+\`5>RG`"$>5KF"`(KL
M<R"_`%7LTSN_)56YY)`XN00`C>R'`#H%5KF"`#;C$/#@``2Y"``UPAI:@GF9
MN0@`.+GH8%'KB0`"``SL:B"_`%7LB0`A'E:Y@@"H[),@OP!5[-,[OR55N>1P
M.KD$`*WLJ0`Z!5:Y@@`VXQ#PZ``$N0@`-<(:6H)YF;D(`#JYZ&!1ZZ<``@`,
M[&@@OP!5[*<`(1Y6N8(`BNQS(+\`5>S3.[\E5;GDD#BY!`"-[(<`.@56N8(`
M-N,0\/``!+D(`#7"&EJ">9FY"``XN>A@4>N)``(`#.QJ(+\`5>R)`"$>5KF"
M`*CLDR"_`%7LTSN_)56YY'`ZN00`K>RI`#H%5KF"`#;C$/#X``2Y"``UPAI:
M@GF9N0@`.KGH8%'KIP`"``SL:""_`%7LIP`A'E:Y@@"*[',@OP!5[-,[OR55
MN>20.+D$`(WLAP`Z!5:Y@@`VXQ#Q```$N0@`-<(:6H)YF;D(`#BYZ&!1ZXD`
M`@`,[&H@OP!5[(D`(1Y6N8(`J.R3(+\`5>S3.[\E5;GD<#JY!`"M[*D`.@56
MN8(`-N,0\0@`!+D(`#7"&EJ">9FY"``ZN>A@4>NG``(`#.QH(+\`5>RG`"$>
M5KF"`(KL<R"_`%7LTSN_)56YY)`XN00`C>R'`#H%5KF"`#;C$/$0``2Y"``U
MPAI:@GF9N0@`.+GH8%'KB0`"``SL:B"_`%7LB0`A'E:Y@@"H[),@OP!5[-,[
MOR55N>1P.KD$`*WLJ0`Z!5:Y@@`VXQ#Q&``$N0@`-<(:6H)YF;D(`#JYZ&!1
MZZ<``@`,[&@@OP!5[*<`(1Y6N8(`BNQS(+\`5>S3.[\E5;GDD#BY!`"-[(<`
M.@56N8(`-N,0\2``!+D(`#7"&EJ">9FY"``XN>A@4>N)``(`#.QJ(+\`5>R)
M`"$>5KF"`*CLDR"_`%7LTSN_)56YY'`ZN00`K>RI`#H%5KF"`#;C$/$H``2Y
M"``UPAI:@GF9N0@`.KGH8%'KIP`"``SL:""_`%7LIP`A'E:Y@@"*[',@OP!5
M[-,[OR55N>20.+D$`(WLAP`Z!5:Y@@`VXQ#Q,``$N0@`-<(:6H)YF;D(`#BY
MZ&!1ZXD``@`,[&H@OP!5[(D`(1Y6N8(`J.R3(+\`5>S3.[\E5>,0\3@`!+GD
M<#K"&EJ">9FY@@`VN00`K;D(`#7LJ0`Z!5:YZ&!1N0@`.NQH(+\`5>S3.[\E
M5>NG``(`#.S3(#H%5NRG`"$>5L`Z`````+GGH'CC@/%```2Y@`!YPHI:@GF9
MN8(`=KGH8!BY"`!UZUD``@`,N0@`?>Q9`"$>5NR7.[\E5>R7(#H%5NQJ(+\`
M5;GG4-KK@P`"``RY@`#3N8(`UKD(`-&Y"`#9N00`F.R3`"$>5NP].[\E5;GG
MD!7L/2`Z!5:Y@@`7XZ#Q2``$XX#Q4``$PJINV>NAPHINV>NAN0@`IKD:`(6Y
M&@"A[&<BOSY5N0@`H^QG`B$>5NPZ.[\E5;GG8!GL.B`Z!5:Y@@`=['TBOSY5
MN1H`@>Q]`B$>5KD(`(/C,/%8``3".F[9ZZ&YYW!6N1H`.;GGH)7L&#N_)56Y
M&@`Y[!@@.@56XY#Q8``$N0@`,<*:;MGKH>S3.[\E5;D:`);LTR`Z!5;L:B*_
M/E7L:@(A'E;CH/%H``2YYV!7PJINV>NAN8(`6+D:`*>Y&@"5['@BOSY5N0@`
MG>QX`B$>5NR).[\E5>R)(#H%5KGG<-:SP0!HXX#Q<``$PHINV>NAN1H`AK/-
M`&:Y@@#3N1H`K;D(`*;L6CN_)57L6B`Z!5;L8R*_/E7C$/%X``3L8P(A'E;"
M&F[9ZZ&YYV`WN1H`%[F"`#GL>2*_/E6Y&@"#['D"(1Y6N0@`A;GG<%;LF#N_
M)56Y@@!:[)@@.@56N1H`%>,P\8``!+D(`!G".F[9ZZ'LFB*_/E6Y&@`V[)H"
M(1Y6[-$[OR55N>>05^S1(#H%5KF"`%CCH/&(``2Y&@`UPJINV>NAN0@`/;D:
M`*?L>"*_/E7L>`(A'E;L@SN_)57L@R`Z!5:YYW#9L\$`>..`\9``!,**;MGK
MH;D:`(FSS0"7N8(`T;D:`*VY"`"I[%H[OR55[%H@.@56[&$BOSY5[&$"(1Y6
MXQ#QF``$N>=@U\(:;MGKH;F"`-.Y&@`7N1H`C>QS(K\^5;D(`(7L<P(A'E;L
M.#N_)56YYW!6[#@@.@56N8(`6N.0\:``!+D:`!7"FF[9ZZ&Y"``3N1H`ENPZ
M(K\^5>S1.[\E5>PZ`B$>5NS1(#H%5KGG,%?CH/&H``2Y@@!8PJINV>NAN1H`
ME;D:`*>Y"`"=['@BOSY5['@"(1Y6[(D[OR55[(D@.@56N>=PT[/!`&CC@/&P
M``3"BF[9ZZ&Y&@"#L\T`-KF"`-&Y&@"MN0@`H^Q:.[\E5>Q:(#H%5NQA(K\^
M5>QA`B$>5N,0\;@`!+GG8-?"&F[9ZZ&Y@@#9N1H`%[D:`(WL>2*_/E6Y"`"%
M['D"(1Y6[)@[OR55N>=P5NR8(#H%5KF"`%KC,/'```2Y&@`5PCINV>NAN0@`
M&;D:`#;LFB*_/E7LT3N_)57LF@(A'E;LT2`Z!5:YYY!7XZ#QR``$N8(`6,*J
M;MGKH;D:`#6Y&@"GN0@`/>QX(K\^5>QX`B$>5NR#.[\E5>R#(#H%5KGG<-FS
MP0!XXX#QT``$PHINV>NAN1H`B;/-`)>Y@@#1[&$BOSY5N1H`K>QA`B$>5KGG
M8->Y@@#3N0@`J;D:`(WL6CN_)57LTR*_/E7L6B`Z!5;LTP(A'E:YY]"6N8(`
MFKD(`(7C$/'8``3L.""_`%7L6#N_)57"&F[9ZZ'L4P`Z!5:Y&@`7N1H`&>R:
M(K\^5;D(`!7LF@(A'E;CH/'@``2YYY!]PJINV>NAN8(`A[D:`*;L82"_`%7L
M$3N_)57L%@`Z!5:Y&@"HXX#QZ``$N0@`H<**CQN\W.L3``(`#+D:`(WL$P`A
M'E;LT2"_`%6YY-!9L\$`*.PZ.[\E5>R*(+\`5;GF$*FY@`"FN8$`I;/-`%+C
M</'P``3">H\;O-SL.``Z!5:Y"`"EN00`5^-P\?@`!+D:`%G">H\;O-SKE@`"
M``SLE@`A'E:YY-!IN8$`&;GHT->Y@``8N8$`%KD(`!6Y"`"CL\$`;>PZ(+\`
M5>RJ.[\E5>RC`#H%5KD(`*'K&``"``SL&``A'E;LT2"_`%6YY-!9[&H@OP!5
M[(H[OR55N>80J;F``*.Y@0"EL\T`5NR&`#H%5N-P\@``!+D(`*6Y"`"HPGJ/
M&[S<ZX,``@`,N00`5^R#`"$>5KD:`%GL.CN_)57LFB"_`%6Y@0`8N>30J+F`
M`!:Y@0`:N0@`%>PY`#H%5N-P\@@`!+D(`#'">H\;O-SK%@`"``RYZ-#7[!8`
M(1Y6[&$@OP!5N>1@6+/!`#VYYA#8N8``V;F!`-6SS0!3[',@OP!5[#,[OR55
M[#<`.@56N0@`U;D(`-/K.0`"``SL.0`A'E:YY&"3N8$`$^.@\A``!+F``!?"
MJH\;O-RY@0`9N00`6KD:`%CLC2"_`%6Y"``5[-T[OR55[-@`.@56N0@`T>R=
M(+\`5>L7``(`#.P7`"$>5N-P\A@`!,)ZCQN\W+GH8&?L<2"_`%6YY'!3N>80
MH[/!`':Y@`"HN8$`I;/-`%?LW3N_)57C8/(@``2Y"`"E[-D`.@56PFJ/&[S<
MN0@`VKD$`%;LK2"_`%6Y&@!3[-T[OR55ZS@``@`,[-H`.@56[#@`(1Y6N>8P
M@;GD<!.Y@`")N8$`@>L9``(`#+D(`(7L&0`A'E:Y"`"-[-$@OP!5N>304[GF
M$)/C8/(H``2Y@`":PFJ/&[S<N8$`E;D(`&>SP0`FL\T`4NQX(+\`5>-@\C``
M!+D(`)7":H\;O-SLB#N_)56Y!`!6[(<`.@56N1H`4[GH@#GKF@`"``SLF@`A
M'E:YY-"IN8$`&;F``!>Y@0`:N0@`%>R#(+\`5>QC.[\E5>,P\C@`!.QH`#H%
M5L(ZCQN\W+D(`&'K%P`"``SL%P`A'E;L<2"_`%6YY'!9N>C0T[GF$#FSP0!M
MN8``.+F!`#6SS0!6X]#R0``$PMJ/&[S<[*8@OP!5N0@`->QF.[\E5;D$`%WL
M:@`Z!5:Y&@!9X]#R2``$ZY@``@`,PMJ/&[S<[)@`(1Y6N>1PB;F!`!FYZ'!]
MN8``&KF!`!BY"``5N0@`-K/!`#?L8R"_`%7L,SN_)57L-@`Z!5:YZ#!1ZQH`
M`@`,[!H`(1Y6[-$@OP!5N>30>;GF$*FY@`"FN8$`I[/-`'/L-2"_`%7LA3N_
M)56Y"`"G[(,`.@56N0@`J.-0\E``!.QZ(+\`5>R*.[\E5<):CQN\W..@\E@`
M!+D:`%G"JH\;O-SKE@`"``SLE@`A'E:YY-!IN8$`&;GHT-JY@``3N8$`%KD(
M`!7LAP`Z!5:SP0!]N0@`@>L3``(`#.P3`"$>5NS1(+\`5;GDT%FYYA"IN8``
MI[F!`*6SS0!7[&@@OP!5[#@[OR55N0@`I>PV`#H%5N.`\F``!,**CQN\W+D$
M`%BY&@!9ZY<``@`,[)<`(1Y6N>30>;F!`!FY@``6N8$`%[D(`!6Y"`"CXX#R
M:``$[#H@OP!5PHJ/&[S<[*H[OR55[*,`.@56N0@`H>L6``(`#.P6`"$>5NQA
M(+\`5;GD8%GL>B"_`%6YZ-#8[(H[OR55L\$`+;GF$*FY@`"CN8$`I;/-`%+L
MAP`Z!5;CT/)P``2Y"`"EPMJ/&[S<N0@`J+D$`%VY&@!9[-H@OP!5ZY,``@`,
M[),`(1Y6[#H[OR55N>1@B;F!`!GL/0`Z!5:Y@``7XZ#R>``$N8$`&,*JCQN\
MW+D(`!6YZ&!:N0@`,>QC.[\E5>QC(#H%5NL7``(`#+/!`&;L%P`A'E;C8/*`
M``3L@2"_`%6YYA!YN>2`J<)JCQN\W+D:`&FSS0"6N8``?;F!`'JY"`!UN>B0
ME^Q9.[\E5>Q9(#H%5K/!`!;K?0`"``SL?0`A'E:Y!`#5L\T`4;GD@*?C8/*(
M``3":LIBP=:YZ("&P#H`````N8$`%[/!`#BY@``3ZX,``@`,N8$`&NR#`"$>
M5KD(`!6SS0!CN0@`'>.@\I``!+GG@-?"JLIBP=:Y@@#9N1H`I^QY(K\^5>QY
M`B$>5N.0\I@`!,*:RF+!UKD:`)BSP0!:L\$`";/-`)6Y&@!M[#$[OR55[#$@
M.@56N0@`-NQ3.[\E5>Q3(#H%5KGG<*BY@@"AN1H`FKD(`)6SS0!0[&$BOSY5
M[&$"(1Y6N>=@U[F"`-/L&3N_)56Y&@!=[!D@.@56N0@`%>RA.[\E5>RA(#H%
M5K/!`"JSS0#2XX#RH``$XZ#RJ``$PHK*8L'6PJK*8L'6N1H`A[D:`*;L<R*_
M/E7L<P(A'E:YYW`V[&DBOSY5N8(`.>QI`B$>5KD:`(.YYV!7N0@`C;F"`%'L
MF#N_)56Y&@"E[)@@.@56N0@`J>S:.[\E5>S:(#H%5NR1(K\^5>,P\K``!.R1
M`B$>5L(ZRF+!UKGGD%:Y&@`WN8(`6+D:`#6Y"``][-,[OR55[-,@.@56XQ#R
MN``$L\$`'<(:RF+!UN/0\L``!+D:`!;"VLIBP=;L:"*_/E6Y&@#9[&@"(1Y6
MN>=@B;/-`)&Y@@"*['HBOSY5N1H`&.QZ`B$>5KD(`!FYYW"&[%$[OR55N8(`
M@^Q1(#H%5N.@\L@`!,*JRF+!UKD:`*:Y!`!M[-,BOSY5N1H`:+D(`&7LTP(A
M'E:YY]`WN8(`,>Q6.[\E5;D:`*/L5B`Z!5:Y"`"E[#H[OR55[#H@.@56XX#R
MT``$PHK*8L'6N1H`A^QQ(K\^5>QQ`B$>5N,0\M@`!+GG<%W"&LIBP=:Y@@!6
MN1H`';D:`(7LUB*_/E6Y"`"#[-8"(1Y6[#@[OR55N>?09^PX(#H%5KF"`&JY
M&@`6N0@`$^PZ(K\^5>PZ`B$>5KGG,&VY@@!H[%$[OR55XY#RX``$[%$@.@56
MPIK*8L'6N1H`E[D:`);L:"*_/E6Y"`"5[&@"(1Y6[(D[OR55[(D@.@56N>=@
M<[/!`$CC@/+P``3"BLIBP=:Y&@"#L\T`-+F"`''CH/+H``3"JLIBP=:Y&@"M
MN1H`I^QQ(K\^5;D(`*/L<0(A'E;L6CN_)56YYW#6[%H@.@56N8(`V>,0\O@`
M!+D:`(W"&LIBP=:Y"`"%N1H`%NQI(K\^5>QI`B$>5NR8.[\E5;GG8%?LF"`Z
M!5:Y@@!:N1H`%;D(`!GLT3N_)57LT2`Z!5;LFB*_/E7C,/,```3LF@(A'E;"
M.LIBP=:YYY!6N1H`-[F"`%BY&@`UN0@`/>S3.[\E5>S3(#H%5N.@\P@`!+/!
M`%W"JLIBP=;CT/,0``2Y&@"FPMK*8L'6[&@BOSY5N1H`V>QH`B$>5KGG8(FS
MS0"5N8(`@;D:`*CL@2*_/E7L@0(A'E:YYX!VN8(`<[D(`*FY&@#7[%H[OR55
M[',BOSY5[%H@.@56[',"(1Y6N00`-^,P("``",`Z`````.,P("``).,0\Q@`
M!,(:RF+!UKD:`!:YZ%!MN>=PV.R6(+\`5;GGH#WL5CN_)56Y&@`3[%D`.@56
MN0@`%>S:(K\^5>M9``(`#.S:`B$>5NQ9`"$>5KGGT#>Y"`!4N>@`?<!:````
M`.-0(!``)+GG8`/`>@````#C<"`8`"3L82"_`%7CH/,@``3"JLIBP=:Y"`#J
MN1H`Z.R!.[\E5;D:`.#LA@`Z!5;C$/"@``2Y"`#HN0@`%L#J`````./@(```
M),`:`````.,0(`@`)-4'\RBP**=T``KK;_-@``0'_KD$`'ZG]/4%P.7___'"
M!P<'!P<'ZV_P,``DQ!@``#_YX_#_8/]QXW`0```"IX0`4[D$`(*Y!`!CXP`@
M``"4N00`DI4`(`"GA`!*[`@`##U^09"0`>,`D```E)4`D`"G=/_V&YCCH'``
M``*GA``?N10`F;D$`+>Y!`!)N00`.+D$`"K`Y?__\$7L)@`)`'Y!*:``E3T@
M`*>$``]!L+`(XZ"P```"IW3_Z;D$`"KK;_#0``0'_D&IH`&YZ7`[N00`*NM#
M``,`"E!`8`#K;_#0``0'_J>I``"G]/_IIY@``*?T_\,'!^NO\%``)./P_LC_
M<;)/`+"Y!`"BZ[L`(``-03#PH+)/`+'2!_$PL"C`Y?__\7#L)@`A`'X8$J<X
M0`!8(/"XP"L``/``[",`"(!VI0^@`.P@`!-@=KD$`"JG.0`"P.7___'6$!*G
M&O__B!``'Z?T``2G&```U0?Q,+`HN10`(:=T``;KK_&(``0'_L#E___Q#^MO
M\#``)./P_L#_<;)/`)#KF0`@``VR3P"1T@?Q.)`H["@`"0!\N00`8I4`(`"G
M=``+U0?Q.)`HIW0`ENMO\7``!`?^P.7___':N00`LNPH__(`?+D$`"O`Y?__
M\$#L*`!F`'Q!H"`3E2X@$Z=T``:5`*`!IX3_\)4N(!.GA`!CIP@``+D$`!:Y
M!``JISD``+)>`#*G%/_^N0D`.J>)``"R7@"!IQ3__KD)`(8:@Z>*``*Y%`"(
MN00`*,#E___NW^.@\*``)*<Y``*Y!`"BN00`2,!0```0E<#E___Q8+D$`"I!
M,/"HP.7__^^9["@`#?]^6`#PP*=(0`#`"P``\`#L!``K@':Y!``JP.7___#'
MN00`*L#E___Q`KD$`"O`Y?__[]WL)O^@`'RY!``KP.7__^Z5N00`)L#E___N
MT*?T_WJ5+J`!IW3_G94`H`*GA/^#I_3_E[D$`"K`Y?___U.G]/_8P.7___!:
M!P<'!P<'ZV_P,``DP!```#ZEX_#_6/]QX[`0```$P%```#!TQ$@``#Z=P#``
M`!`WLD\`H.NJ`"``#;)/`*'C*Z````3`8```$9+`Y?__\0*Y!`!6Y4CPH```
MP$````S&XRN@```$P#```!`GP.7__^]AZV_PV``$!_X'!P<'ZW_P.``DX_#P
M`/]QXP#_^``@X_#_6/]QXP#PH``@XQ#PH`%QN00`@T&0\*"R3P"PN00`HNN[
M`"``#;D$`#FR3P"QT@<0`+`HITD/_\`@```0`,#E___NS^PL`!(`?NP"__\`
MV!@2N10`($$R\*"5`#``IW0`(NP&`!\`?L!0```^+N/@4```!+D$`$BY!``Z
MXRZP```$P.7__^YMXT#PH`%QU0=``+`HIW0`*>M_\.`!!`?^&!"Y%`!QN00`
M*;D$`$>G.0`OP.7__^ZE["C_V`!\N00`2<"````^`;D$`%?CD(````2Y!``Z
MXRFP```$P.7__^]`I_3_T\#E___OF^MO\#``)./P_T#_<;)/`&#K9@`@``VR
M3P!AE3TP`-('\+A@*$&@,`&YXG"CIP@``+D$`!JGB0``N00`LK)>`(&G%/_^
M03#PM+D)`(K`Y?___;;L*`"7`'RG"```I]D``+D$`!*R7@#1IQ3__KD)`-+L
MC0!VP&7C</"T`!3$V```/9KK=P`#``WC(+```)2Y!`!+E0"P`*=T``VG]`#P
M04!``>,@0```E)4`0`"GA``%[";_]SU^N0D`2[D4`)1!*)`"N00`A^.`T```
M",#E___M8N,@@```).PH`#D`?.,PT```!.,`L```D.-7,```!$(`4`!!X+`!
M&'#L!@`0`'RG]``\XQ#@``"00A"P`4'@X`$8<>P8`#(`?$)P\*"Y!`"UE3WP
MH$%04`&G=/_MDCVP`*?9``#C3:```)!"3;`!I]L``>Q&__D`?-4'\+A@**=T
M`*#K;_#P``0'_J>9``#CB:```)!"B2``IYL``>R&__D`?*?T_^NY!`"UI_3_
MV<38```]&.-PT```!.,0<````J>$`'BY!`!'IY@``!@IIYH``4%`0`CC,$``
M``*G=/_XIRH``[D4``+K,``#``WC,/"H`"3`4```/6WC$%```!*G=``\P.``
M`#UEXR#PJ``$Y4S@```!P.7__^S4XR#PH``D["C_JP!\N00`-^-0\*@`!+D4
M`'GK=P`#``VY!`!'P.7__^]OXR#PH``$XR#0```D4)#PM.-0\*``!*>:``&Y
M%`"9ZSD``P`-0>-0`.5(X````*?T_R'C,/"H``2Y!``GP.7__^V.XR#PH``D
MXR#0```D["C_<@!\N10`">MP``,`#:?T_]>GF0``I_3_(.5(\*@`$*>8``"G
M]/^=P.7__^Y0!P>R3P`@P!```#R>ZS(`(``-XT`0```$LD\`,<!0```N:^,D
M,```!,1(```\D<`P```.*\#T___O`^MO\#``)./P\`#_<>,`__@`(./P\`#_
M<>,`__@`(./P_TC_<>,`\+``(.,0\+`"<;)/`)#KF0`@``VR3P"1X[#PKP%Q
MT@<0`)`HP.7__^W+P`````XDXP#PH``DN00`8J=)$`&G.0`"N00`*\!0```.
M$$&`\*[`Y?__[K6Y!``KN00`.*=)$`#`Y?__[,SL)``Q`'[L<@`!`-BY!`!B
MN10`=[D$`"?`Y?__[`VY!`"B["@`$@!\N10`MKD$`%>Y!``XN00`2\#E___L
M?4$KH`"2`"``XS#PL`)QU0<P`)`HIW0`#+D$`"KK;_#H`@0'_J>I``"G]/_P
MP.7__^VT!P?`]/___X`'!^MO\#``)./P\`#_<>,`__@`(./P_K#_<>,`\4@`
M(.,0\4@!<;D$`+*Y!`"3LD\`<$$P\+3K=P`@``W`(```#:ZR3P!QT@<0`'`H
MP.7___O+ISD`+[D$`**Y!``KP.7__^V.["@`&0!\P"````V<N00`.\#E___]
MV[D$`"OC@/%(`7'5!X``<"BG=`#MZV_Q@`$$!_ZY!``IP.7__^R0P#````V(
MP.7__^O:N00`8NPH_]T`?$&0\4A!@/"XE0!@`*>$`*3LJ``/`'RG"```N00`
M-KD$`"JR70`RIQ3__J>$`(2G"```ITD``+D$`%:R7@!%IQ3__KGI8"3C$$__
M_W'L80`WH&6YZ6`!IP$``:>$``Z5+Q``IW0`()(`$`#C$!___W'L80`9@&3K
MX``!``R5+Q``IW0`$9(`$`#K+Q___U6G=``*ZP`?__]2XQ`?_O]QI^?_[Z<(
M``"G*0``N00`-K)>`".G%/_^N0D`)J<(``"G20``N00`6Z?I#_^R7@!%IQ3_
M_KD)`$M!!"`![`[_;2!EP!````T.X[#PJ``DXQ#PH``DISD``KD$`"G`4```
M#7BG21``P.7__^V0N00`.+D$`"G`Y?__Z\GL)@`-`'Y88/#0I3^``,!K``#P
M`.QC`"B`=L`P```,Y*<I``#`Y?__ZS2Y!`!B["C_-P!\E0!@`*=T_V#LJ``'
M`'R5+J``IX0`":<I``'`8```#+VG]/^GE0"@`:>$_]^G]/_UN00`*:<Y``'`
MY?__[4#L)O_4`'ZY!``YP"````RLP.7___SMN00`*<#E___KL*?T_P_`Y?__
M['OKO_!8`"2G.0`ON00`LN/P_V#_<<#E___M#D$0(`&Y`@`BN00`*[GB<"'K
MO_#X``3`]/__ZY`'!^N?\$@`)./P\`#_<>,`__@`(./P_UC_<>,`\*``(+)/
M`*#C$/"@`7'KJ@`@``VR3P"AT@<0`*`H["@`9`!\E0`@`*>$`%^G"```IYD`
M`+D$`#*R7@"3IQ3__J<)$`"Y"0"2[$D``0#9[$``;R!EN00`,D&P\*"Y!``K
MP.7__^T_XUF___]Q[%L`'\!EN>FP):=1``&G=`!'ZT(``0`,E2]0`*=T`!&2
M`%``ZR]?__]5IW0`"NL`7___4N-07_[_<:='_^^Y!``KISD`+\#E___LENPH
M`!<`?.PK`#,@9;D$`"O`Y?__ZQOCX/"@`7'5!^``H"BG=``MZY_P\`$$!_[C
M$/"@`7'5!Q``H"BG=``AP"````ORZY_P\`$$P/3__^K^E2]0`*=T_\^2`%``
MXU!?__]Q[%O_LF!DI_3_Q9(`(`"G]/_.IRD``*?T_\_`Y?__Z[4'!P<'ZZ_P
M4``DX_#_4/]QLD\`H.NJ`"``#;)/`*%!L/"DT@?PJ*`HN00`.\`@```+R<#E
M___YW>PH`"X`?.-`\*0`%,0H```YT.L4``,`#>,0(```".-0$`@`!.-0$```
M).Q8_^,`?.,`$!``!.,`$`@`)$$0$`CL!O_X`'RY!``[P"````N>P.7___FR
M[";_V`!\N00`.\`@```+F,#E___YI^PH`"X`?.,0\*0`%,18```YFNOA``,`
M#>/@4```".,`X`@`!.,`X```).P(_^,`?.,PX!``!.,PX`@`)$'@X`CL-O_X
M`'RY!``[P"````MMP.7___E\[";_V`!\N00`.\`@```+9L#E___Y<>PH`"X`
M?.-0\*0`%,3H```Y9.M%``,`#>-`X```".,P0`@`!.,P0```).PX_^,`?.,@
M0!``!.,@0`@`)$%`0`CL)O_X`'RY!``[P"````L[P.7___E&[";_V`!\N00`
M.\`@```+-<#E___Y.^PH`"X`?.,P\*0`%,0H```Y+NL3``,`#>,0(```".-`
M$`@`!.-`$```).Q(_^,`?.,`$!``!.,`$`@`)$$0$`CL!O_X`'RY!``[P"``
M``L*P.7___D0[";_V`!\N00`.\`@```+`\#E___Y!>PH`"X`?.,0\*0`%,1(
M```X^.M1``,`#>-00```".,`4`@`!.,`4```).P(_^,`?./@4!``!./@4`@`
M)$%04`CLYO_X`'RY!``[P"````K8P.7___C:[";_V`!\N00`.\`@```*U<#E
M___XS^PH`"X`?.-`\*0`%,18```XPNLT``,`#>,P4```"./@,`@`!./@,```
M).SH_^,`?.,@,!``!.,@,`@`)$$P,`CL)O_X`'RY!``[P"````JJP.7___BD
M[";_V`!\N00`.\`@```*=\#E___XF>PH`"X`?./@\*0`%,0H```XC.L>``,`
M#>,0(```".,P$`@`!.,P$```).PX_^,`?.,`$!``!.,`$`@`)$$0$`CL!O_X
M`'RY!``[P"````I,P.7___AN[";_V`!\N00`.\`@```*;\#E___X8^PH`"X`
M?.,0\*0`%,0X```X5NM!``,`#>-`,```".,`0`@`!.,`0```).P(_^,`?.-0
M0!``!.-00`@`)$%`0`CL5O_X`'RY!``[P"````I$P.7___@X[";_V`!\N00`
M.\`@```*/L#E___X+>PH`"X`?.,P\*0`%,1(```X(.OC``,`#>/@0```".-0
MX`@`!.-0X```).Q8_^,`?.,@X!``!.,@X`@`)$'@X`CL)O_X`'RY!``[P"``
M``H3P.7___@"[";_V`!\N00`.\`@```*#<#E___W]^PH`"X`?.-0\*0`%,3H
M```WZNL5``,`#>,0X```".,@$`@`!.,@$```).PH_^,`?.,`$!``!.,`$`@`
M)$$0$`CL!O_X`'RY!``[P"````GBP.7___?,[";_V`!\N00`.\`@```)I,#E
M___WP>PH`"X`?.,0\*0`%,0H```WM.LQ``,`#>,P(```".,`,`@`!.,`,```
M).P(_^,`?.-`,!``!.-`,`@`)$$P,`CL1O_X`'RY!``[P"````EYP.7___>6
M[";_V`!\N00`.\`@```)IL#E___WB[D$`#+L*``)`'S`(```"9'`Y?__^:2Y
M!``[P"````F<P.7___=XN00`,NPH``D`?,`@```)FL#E___YD;D$`#O`(```
M"9C`Y?__]V6Y!``R["@`&@!\P"````DXP.7___E^U0?PJ*`HIW0`(\`P```)
MD\`@```)2NNO\0``!,#T___Y;;D$`#O`(```"7S`Y?__]T&Y!``R["C_Y0!\
MP"````E"P.7___E:I_3_W,#E___H[0<'!P?KO_!8`"3`(```"3+C\/]0_W&R
M3P"P03#PI.N[`"``#;)/`+'2!_"HL"C`Y?__]Q?L*``A`'Q#$"``&"'`)P``
M`#"YA``"N0,`,*<1`/_K4P`_``RG2```N?*`5-4'\*BP*+D4`"6G=``*Z[_Q
M"``$!_ZG6```I_3_\\#E___HJV``\(!@(/"(8$#PD&!@\)CK/_`8`"3$&```
M-P7C\/\X_W&Y!`!"00#Q:+)/`"!!4/#(ZS(`(``-LD\`,>,@$```!-('\,`P
M*.-0\+@`).,`\+``).5(\*```>5(\*@``$%0\*"G.0`"P.7__^A$IRD`_\#E
M___G_^N/\$``)./@\`#P<>/P\`#_<>,`__@`(+DA`/ZG)/_XN00`_N/P_U#_
M<>,`\*@`(.,0\*@0<:<Y``"Y!`""LD\`H*=)``+KJ@`@``VR3P"A0;#PH-('
M$`"@*,#E___FC\`Q__\``.R2__\`V>P),(``5;D$`""G"___N8$``Z<+``&Y
M`@"9N>*@`KD)`)#LE`"*`'RY!``YN00`**=)``#`Y?__YFSL*`"8_WRY!``[
MN00`*,!!``$`",#E___H;^PH`(7_?KD4`$+L3`!C!WWC%+_X_W'L&P!=0&7L
M43Z_`%7$Z```-G/CX!```""GA`!HXQ`?__]Q[!L`3$!E[%@`)`!\[%@`%@%\
M[%@`"P)\X^`0```@IX0`5.,0'___<>/@$```(*>$`$SC$!___W'CX!```""G
MA`!$XQ`?__]Q[!L`*$!EX^`0```@IX0`.>,@'___<;D$`!+CX"```""GA``O
MXQ`O__]QX^`0```@IX0`)^,0+_[_<>/@+_[_(*>$`!_C$"_]_W'L&__>H&7"
ME``!``#``?__``#LD/]\8&2G*?__XX#PJ!!QU0>``*`HIW0`&.N/\/`0!`?^
MN>FP(;D(`"FG]/_PP"````@4P.7___[<P"````@'P.7___[6P.7__^=[Z^_P
M<``DX_#_8/]QP.7__^5BP.7__^4_["@`!@!\XR`@```$Z^_Q$``$!_X'!P<'
MZV_P,``DX_#_0/]QLD\`H+D$`&+KJ@`@``U!,/"TLD\`H<`@```'XM('\+B@
M*,#E___UC>PH``D`?+D$`+*5`"``IW0`$M4'\+B@**=T`$^Y!``VP"````?)
MZV_P\``$P/3___>8IP@``+D$`#NY!``6IRD``*=)``"R7@`AIQ3__K)>`$.G
M%/_^N0D`)KD)`$M!DD`"N00`*<#E___E0^.P\*@`),`````'..,`\*``)+D$
M`$FY!`"RP%````>FISD``L#E___GOM4'\+B@**=T``VY!``[P"````>'ZV_P
M\``$P/3___=6P.7__^;KZV_P,``DLD\`$./P_BC_<>LQ`"``#;)/`#'C,/#(
M`"32!_'0,"C`0```-4U!@/#4N00`.-)'\/A`$-(/\.!`6-('\/!`:.,@\,``
M),`@```&X<#E___U`^PH``D`?+D$`+*5`"``IW0"F,#E___DH\#E___D@.PH
M`3D`?..@(````J>$`3.G"```IRD``+D$`%JR7@`EIQ3__KD)`"KKL@`!``VG
MNP`!N00`*\#E___DPN,`H```E+D$`)*5`*``IX0"?KD$`'NY!`#2N00`2[D$
M`"FY%@!@P%````<;ISD``D&@H`'`Y?__YS6Y(0![N00`2[GBH$?C`*```)2Y
MZ;!4IUL``KDA`%2YXE!4N>E`*T&0D`+CLE_^_W&5`*``IW3_UD%@\1C`(```
M!L*G]``)IVL`".,@;_C_`J>$`""Y!``XP.7___2*N00`<NPH__(`?)4`(`"G
MA/_MP.7___3F["C_Z`!^N00`)\#E___E8KD$`&+L)@`=`'Q!D/#XXV"0```"
MIX0`%94`8`"GA`"IN00`)L#E___TR>PF`)0`?J>;``CC8)````*G=/_OIP@`
M`+D$`.VY!`"FI[D``*<9``"R7@"ZIQ3__K)>`!ZG%/_^N0D`';D)`+8:L:>Z
M!`2Y%`"KN00`*L#E___D(\`````&'./0\+``).,`\*``)+D$`'*G.0`"N00`
M2L#0```&B./0\*@`),!0```&?<#E___FF+D$`">G.0'`P.7__^6!["8`"_]^
MP.7__^5+6#`@`.PV`8P1?D'0\4"Y!``GN00`/<#E___E[1BR["8`#0!^6$#Q
M6*=80`#`2P``\`#L10"&@':Y!`!GQ(@``#02XW#PP``$P$````9LXU!P```$
MXR"````$ISD``L#E___EN:>9``#C8/#(``35!_'08"BG=`(>N00`*>MO\@@`
M!`?^N00`)J>;``C`Y?__Y+*Y!`!B["C_50!\I_3_:J=I``"G]/]F06#PX.,@
M8````J>$`!6Y!``XP.7___.O["@`!P!\E0`@`*=T`!VG:P`(XR!@```"IW3_
M[Z<I``VG>0`-I[D`#<#E___CA,"@```%[+D$`)*Y!`#2IP@`4Z?T_L;`Y?__
MY':G:P`(N00`HNPH_\T`?*<(``"GZ0``N00`,K)>`..G%/_^N0D`XNN^``$`
M#:>[``&G]/Z76&#Q7,#E___C%^QB_WA@=EB0\5BG*`'`P)L```'_[)+_;F!V
MN00`*L#E___C1;D$`#BY!`"2P"````8`P.7___-/N00`,NPH`0``?.,0\,``
M!.,@$```!,#E___W4;D$`&+L*`#R`'RG"```ITD``+D$`#:R7@!#IQ3__KD)
M`$;L3``>`WZY%`!4P!````79XR5O_/]QLET`$J<4__ZG=``/[$@!0P1^ITK_
M^[D4`.1!3F``E2]``*>$`3BY!``XP"````46P.7___,*["@`Q0!\XP`@``"4
M[`@`OP!^[`@`O#!^P#````4\P"````4!N00`9\#E___U%\#E___D;,!0```&
M!L`0```$TKD$`-+C4/"P`"2Y!`!*N00`*>,0\*``)./0\*@`),!0```%G:<Y
M``+`Y?__Y4^G]``TP.7__^0*6"`@`*<N`!&G=``UP.7__^1!P#````2JN00`
M`J>Z``'`@```!=3C,/"@`"2Y%`#;N00`9[D$`$JY!``IXX#PN``DXP#PJ``D
MP%````5SX]#PL``DISD``L#E___E&[D$`"FG.0'`P.7__^0$["C_Q_]^N00`
M)\#E___DS+D$`#G`(```!&;`Y?__]*RY!``IP.7___S?I_3^J+D4`$/C$/#`
M``2Y!`!GXU`0```$Q"@``#*8XT#PH``DISD``L!````$TN,@(```!,#E___D
M0J?T_HG`Y?___+WC</#(``35!_'0<"BG=`"DN00`*^MO\@@`!,#T___C/;D$
M`-*G]/VRX^#PP``$XV#@```$I_3_"[D$`":G.0``P.7__^2*N00`8NPH_SX`
M?L#E___[AKD$`(+L)/\V`'RG20``XS"/]O]QN00`)L#E___B,[D$`"9!,/#:
MITD`!L#E___D.NPF`&H&?,`P```D!=4%,`#PVJ=T_Q?C,(_._W&G20``N00`
M)L#E___B%;D$`":Y!``]ITD`*,#E___D'.PF`$PH?,#@```%$\!0```#W[D$
M`$KC4/"@`"2Y!`!GN00`*9(`\6CCX/"P`"3CT/"H`"3`4```!*"G.0`"P.7_
M_^1:I_3_2>,P\,``!.-0,`@``J>$_L2G"```IQD``+D$`"6R7@`2IQ3__KD)
M`!7L'/ZV`WWCX5_\_W'`0```!'.R70!.IQ3__KGB@&6G]/ZGP.7__^-PP"``
M``1HP.7___K"!P<'!P<'ZW_P.``DX_#_4/]QP*```#&RLD\`L.,0H```!.N[
M`"``#;)/`+'CD;````1!@/"DT@?PJ+`HT@"0L9"PN00`.,`@```#@\#E___Q
MA>PH``<`?)4Q(`"GA`#2P.7___>'XR"@```$XY*P```$N00`*:=9``.G20`!
MP#````1!P.7__^&UN00`DNPH`!\`?.,P(!``!.-PH```!.,P,```!,!````$
M+N,GL```!,#E___AKN-`D!``!.,P0```!)%`,`VG=`"OXW"@```$IUD``^,G
ML```!*=)``'`,```!!3`Y?__X82Y!`"2["@`'`!\N00`.,`@```##L#E___Q
M*^-0D!``!+D$`$+C,%````3L*`![`'SC)[````3`Y?__X7;CH*````2G20`!
MXWJP```$P#````/IN00`)\#E___@QL!````#[+D$`#*Y!``GP.7__^%<N00`
M.,`@```"UN.*L```!)(`@+'`Y?__\//$*P``,6RY!`"2["@`+`!\N00`*:<Y
M`<#`Y?__XE#L`@`!`-CL#``6`7_L*``3$7ZY!`!2Q+@``#%.N00`2<`@```#
MRN,PL```!,#E___BU]4'\*BP**=T`#7K?_#H``0'_L0H```Q-\#E___[D,0K
M```Q-;D$`)+L)O_,`'S`(````YG`Y?__XKJ5`"`!IX3_-Z?T_RS$Z```,1VY
M!``CXS#@```$P.7___)!I_3_@^,GL```!,#E___B0:?T_TW`Y?__XDP'!^N?
M\$@`)./P_U#_<;)/`*"Y!`"RZZH`(``-03#PI+)/`*'`(````H32!_"HH"C`
MY?__\'7L*``3`'SC$"```)3L&``-`'[L&``*,'[LN``'`'R5`+``IW0`"]4'
M\*B@**=T`#7KG_#X``0'_KD$`"O`Y?__];2G.0`ON00`DL#E___BJ;D"`")!
M`"`!N00`*;GB<"#`Y?__X2ZG20`$P#````*@P.7__^"V[";_V`!^U0?PJ*`H
MIW0`"KD$`"OKG_#X``3`]/__\-K`Y?__X>/K[_!P`"2G*0"`X_#_8/]QP.7_
M_^`(P#%G12,!P`_OS:N)XS`@```DXP`@"``DP$^8NMS^P%$0,E1VXT`@$``D
MXU`@&``DP#_#TN'PY4@@*```XS`@(``DY4@@,```Y4P@>```Z^_Q$``$!_X'
M!P<'ZV_P,``DN00`[^/P_U#_<:?K__!@@.``8*#@"+D$`+*Y!`"DXU`@*``$
MZQ0``P`-XT`@,``$N0@`%>PD``$`V>P!(+\`5;DQ`%&YXB!"XP"P*``DZVH`
M'0`,N>A`=N-PL#``)+D$`&/CT+!X`!*G=`"707"P..RL`(`_?NO:``8`WNSM
M(+D&5:?:___L7O_``-E!'F``ZX4`!@`,N18`3:>+``&SP0"!L\$`I+D$`);L
M"#Z_`%6GA``K[`@`&@%\[`@`#0)\TC]P`&``N00`*T&08$#`Y?__Y#+2/W``
MD`"Y!``K09"00,#E___D*-(_<`"0`+D$`"M!D)!`P.7__^0>L\T`*.R2`"J`
M9.N(``(`#-(_<`"0`+D$`"O`Y?__Y`[2/W``D$"Y!``KP.7__^0&TC]P`)"`
MN00`*\#E___C_M(_<`"0P+D$`"M!D)$`P.7__^/TIX?_WK/-`#JGJO_`B=``
M!NOC``8`#1NM06Y@0+D4`*JY!``VN00`)[D$`$K`Y?__X@=0H+!X:(#PH&B@
M\*CK;_#@``0'_J>8`$`;G1F:07"P.+GR,)JY!``GN1@`+;D4`(FY!`!(P.7_
M_^'J&#E:,+!X4#"P>.PV_^!`?ANIN00`*[D(`&BY%`"JP.7__^.LI_3_2`<'
M!P<'!^N/\$``)+D$`+/C@#`H``3CD#`P``3L&#J_/57C\/]@_W&Y%``Q04.P
M.)*`0`"G&@`!N00`HKD4`"%!,K`X[!P`23A^IT@`0+GY$"3L00`*@':G*O__
MN18`$L80````2[D$`"O`Y?__XW+7-[`XL#BG.0``[#D`!V!5[#D(#V!5[#D0
M%V!5[#D8'R!5N00`*^R#`!\`5>.`L'``),#E___C5M(#H`"P!+D$`"O2`Z`$
ML`S2`Z`(L!32`Z`,L!S2`Z`0L"3KC_#@``3`]/__X,NG"``XN?D04.P!_\R`
M=J=:__^Y%@#EQN`````(I_3_PM<`,``P`-<`,``P``<'!P?$6```+J3`]/__
MWFT'!P<'ZV_P,``DXQ#P>``$I_O_8.,0\```),#````M>>-`\1``!.MO\-``
M!`?T``````````(``25S+R5S`$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E
M<@!);G1E<FYA;',Z.E!!4CHZ0D]/5```+W!R;V,O<V5L9B]E>&4``"]P<F]C
M+R5I+R5S`&5X90`N`%!!4E]414U0``!005)?4%)/1TY!344``#H`+P!015),
M-4Q)0@``4$523$Q)0@!015),-4]05```4$523$E/``!005)?24Y)5$E!3$E:
M140`4$%27U-005=.140`4$%27T-,14%.`%!!4E]$14)51P!005)?0T%#2$4`
M4$%27T=,3T)!3%]$14)51P``4$%27T=,3T)!3%]435!$25(`4$%27U1-4$1)
M4@``4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X``#$`;'-E96L@
M9F%I;&5D``!R96%D(&9A:6QE9`!,1%],24)205)97U!!5$@`4UE35$5-```E
M,#)X```E<R5S)7,E<P``<&%R+0``)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@
M<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@``)7,Z('!R:79A
M=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V92!I
M="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@``4$%42```<&%R;```+G!A
M<@``<VAO<G0@<F5A9```)7,E<V-A8VAE+25S)7,``"5S)7-T96UP+25U)7,`
M)7,E<W1E;7`M)74M)74E<P``&`!P97)L```P`%!!4CHZ4&%C:V5R.CI615)3
M24].```Q+C`V,P!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0``
M)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S
M(&9A:6QE9"`H97)R;F\])6DI"@``+64``"TM``!E=F%L("=E>&5C("]U<W(O
M8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN
M9R!U;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D4$%2
M7TU!1TE#+"`D1DE,15]O9F9S971?<VEZ92P@)&-A8VAE7VYA;65?<VEZ92D[
M"D)%1TE.('L*)%!!4E]-04=)0R`](")<;E!!4BYP;5QN(CL*)$9)3$5?;V9F
M<V5T7W-I>F4@/2`T.R`@(",@<&%C:R@B3B(I"B1C86-H95]N86UE7W-I>F4@
M/2`T,#L*)%!+6DE07TU!1TE#(#T@(E!+7#`P,UPP,#0B.PI]"G-U8B!F:6YD
M7W!A<E]M86=I8PI["FUY("@D9F@I(#T@0%\["FUY("1C:'5N:U]S:7IE(#T@
M-C0@*B`Q,#(T.PIM>2`D8G5F.PIM>2`D<VEZ92`]("US("1F:#L*;7D@)'!O
M<R`]("@D<VEZ92TQ*2`M("@D<VEZ92TQ*2`E("1C:'5N:U]S:7IE.R`@("`@
M(",@3D]413H@)'!O<R!I<R!A(&UU;'1I<&QE(&]F("1C:'5N:U]S:7IE"G=H
M:6QE("@D<&]S(#X](#`I('L*<V5E:R`D9F@L("1P;W,L(#`["G)E860@)&9H
M+"`D8G5F+"`D8VAU;FM?<VEZ92`K(&QE;F=T:"@D4$%27TU!1TE#*3L*:68@
M*"AM>2`D:2`](')I;F1E>"@D8G5F+"`D4$%27TU!1TE#*2D@/CT@,"D@>PIR
M971U<FX@)'!O<R`K("1I.PI]"B1P;W,@+3T@)&-H=6YK7W-I>F4["GT*<F5T
M=7)N("TQ.PI]"FUY("@D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4L
M("5-;V1U;&5#86-H92D["D5.1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*
M<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR
M97%U:7)E($9I;&4Z.E-P96,["FUY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M
M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PIO=71S*'%Q6U)E;6]V:6YG(&9I;&5S
M(&EN("(D<&%R7W1E;7`B72D["D9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@
M>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I
M<B`D<&%R7W1E;7`["FEF("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I
M;C,R)RD@>PIM>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H"E1%35!,051%(#T^
M("=T;7!86%A86"<L"D1)4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D
M=&]P9&ER*2P*4U5&1DE8(#T^("<N8VUD)RP*54Y,24Y+(#T^(#`L"BD["FUY
M("1F:6QE;F%M92`]("1T;7`M/F9I;&5N86UE.PIP<FEN="`D=&UP(#P\(BXN
M+B(["G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A
M<E]T96UP)PII9B!;(%PA("UD("<D<&%R7W1E;7`G(%T[('1H96X*8G)E86L*
M9FD*<VQE97`@,0IX/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R1F:6QE;F%M
M92<*+BXN"F-L;W-E("1T;7`["F-H;6]D(#`W,#`L("1F:6QE;F%M93L*;7D@
M)&-M9"`]("(D9FEL96YA;64@/B]D978O;G5L;"`R/B8Q("8B.PIS>7-T96TH
M)&-M9"D["F]U=',H<7%;4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@
M<&5R9F]R;2!C;&5A;G5P.B`D9FEL96YA;65=*3L*?0I]('T*0D5'24X@>PI)
M;G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ
M4$%2.CI"3T]4.PIE=F%L('L*7W!A<E]I;FET7V5N=B@I.PIM>2`D<75I970@
M/2`A)$5.5GM005)?1$5"54=].PIM>2`E<WES(#T@*`IP871H7W-E<"`@("`]
M/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@("`@("`@
M/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z
M("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G
M7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I.PIO=71S*'%Q6UPD<')O
M9VYA;64@/2`B)'!R;V=N86UE(ETI.PI?<V5T7W!A<E]T96UP*"D["F]U=',H
M<7%;7"1%3E9[4$%27U1%35!](#T@(B1%3E9[4$%27U1%35!](ETI.PIM>2`H
M)'-T87)T7W!O<RP@)'-T87)T7V]F7T9)3$5?<V5C=&EO;BD["DU!1TE#.B![
M"FQO8V%L("1324=[7U]705).7U]](#T@<W5B('M].PIU;FQE<W,@*&]P96X@
M7T9(+"`G/#IR87<G+"`D<')O9VYA;64I('L*;W5T<RAQ<5M#86XG="!R96%D
M(&9R;VT@9FEL92`B)'!R;V=N86UE(ETI.R`@(R!D;VXG="!U<V4@)"$@:&5R
M92!A<R!I="!R97%U:7)E<R!%<G)N;RYP;0IL87-T($U!1TE#.PI]"FUY("1M
M86=I8U]P;W,@/2!F:6YD7W!A<E]M86=I8R@J7T9(*3L*:68@*"1M86=I8U]P
M;W,@/"`P*2!["F]U=',H<7%;0V%N)W0@9FEN9"!M86=I8R!S=')I;F<@(B10
M05)?34%'24,B(&EN(&9I;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0SL*
M?0IO=71S*")&;W5N9"!005(@;6%G:6,@870@<&]S:71I;VX@)&UA9VEC7W!O
M<R(I.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE
M("T@;&5N9W1H*")<,$-!0TA%(BDL(#`["G)E860@7T9(+"`D8G5F+"!L96YG
M=&@H(EPP0T%#2$4B*3L*:68@*"1B=68@;F4@(EPP0T%#2$4B("8F("1B=68@
M;F4@(EPP0TQ%04XB*2!["F]U=',H(DYO(&-A8VAE(&UA<FME<B!F;W5N9"(I
M.PIL87-T($U!1TE#.PI]"F]U=',H<7%;0V%C:&4@;6%R:V5R("(D8G5F(B!F
M;W5N9%TI.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M("1&24Q%7V]F9G-E=%]S
M:7IE+"`P.PIR96%D(%]&2"P@)&)U9BP@)$9)3$5?;V9F<V5T7W-I>F4["FUY
M("1O9F9S970@/2!U;G!A8VLH(DXB+"`D8G5F*3L*;W5T<R@B3V9F<V5T(&9R
M;VT@<W1A<G0@;V8@1DE,17,@:7,@)&]F9G-E="(I.PIS965K(%]&2"P@)&UA
M9VEC7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE("T@)&]F9G-E="P@,#L*)'-T
M87)T7V]F7T9)3$5?<V5C=&EO;B`]('1E;&P@7T9(.PIM>2`E<F5Q=6ER95]L
M:7-T.PIR96%D(%]&2"P@)&)U9BP@-#L@("`@("`@("`@("`@("`@("`@("`@
M("`@("`C(')E860@=&AE(&9I<G-T(")&24Q%(@IW:&EL92`H)&)U9B!E<2`B
M1DE,12(I('L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U
M;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ
M<5M5;G!A8VMI;F<@1DE,12`B)&9U;&QN86UE(BXN+ETI.PIM>2`D8W)C(#T@
M*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N
M9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO
M*3\H+BHI*%PN+BHI?"D["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@
M)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FEF("AD969I;F5D*"1E>'0I(&%N
M9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`D9FEL96YA
M;64@/2!?<V%V95]A<R@B)&-R8R1E>'0B+"`D8G5F+"`P-S4U*3L*)%!!4CHZ
M2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PHD4$%2
M.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["GT*
M96QS92!["B1-;V1U;&5#86-H97LD9G5L;&YA;65](#T@>PIB=68@/3X@)&)U
M9BP*8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U;&QN86UE+`I].PHD<F5Q=6ER
M95]L:7-T>R1F=6QL;F%M97TK*SL*?0IR96%D(%]&2"P@)&)U9BP@-#L*?0IL
M;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*
M<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PIM>2`D:6YF;R`]
M("1-;V1U;&5#86-H97LD;6]D=6QE?3L*<F5T=7)N('5N;&5S<R`D:6YF;SL*
M9&5L971E("1R97%U:7)E7VQI<W1[)&UO9'5L97T["B1)3D-[)&UO9'5L97T@
M/2`B+VQO861E<B\D:6YF;R\D;6]D=6QE(CL*:68@*"1%3E9[4$%27T-,14%.
M?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*;7D@)&9H(#T@24\Z
M.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`B0V%N)W0@8W)E871E('1E;7`@
M9FEL93H@)"$B.PHD9F@M/F)I;FUO9&4H*3L*)&9H+3YP<FEN="@D:6YF;RT^
M>V)U9GTI.PHD9F@M/G-E96LH,"P@,"D["G)E='5R;B`D9F@["GT*96QS92![
M"FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D:6YF;RT^>V-R8WTN<&TB+"`D
M:6YF;RT^>V)U9GTI.PHD:6YF;RT^>V9I;&5](#T@)&9I;&5N86UE.PIO<&5N
M(&UY("1F:"P@)SPZ<F%W)RP@)&9I;&5N86UE(&]R(&1I92!Q<5M#86XG="!R
M96%D("(D9FEL96YA;64B.B`D(5T["G)E='5R;B`D9F@["GT*9&EE(")";V]T
M<W1R87!P:6YG(&9A:6QE9#H@8V%N)W0@9FEN9"!M;V1U;&4@)&UO9'5L92$B
M.PI]+"!`24Y#*3L*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!005(Z.DAE
M879Y.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.CI(
M96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PIR97%U:7)E
M($E/.CI&:6QE.PIW:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E
M<F5Q=6ER95]L:7-T*5LP72D@>PIU;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O
M<B`D9FEL96YA;64@/7X@+T)31%!!3B\I('L*:68@*"1F:6QE;F%M92`]?B`O
M7"YP;6,_)"]I*2!["G)E<75I<F4@)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D
M9FEL96YA;64@=6YL97-S("1F:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN
M<&PD+SL*?0I]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["GT*
M:68@*"1B=68@;F4@)%!+6DE07TU!1TE#*2!["F]U=',H<7%;3F\@>FEP(&9O
M=6YD(&%F=&5R($9)3$4@<V5C=&EO;B!I;B!F:6QE("(D<')O9VYA;64B72D[
M"FQA<W0@34%'24,@.PI]"B1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L@
M("`@("`@("`@("`@("`@(R!S=&%R="!O9B!Z:7`*?0IM>2!`<&%R7V%R9W,[
M"FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*9&5L
M971E("1%3E9[4$%27T%04%]2155317T[(",@<V%N:71I>F4@*%)%55-%(&UA
M>2!B92!A('-E8W5R:71Y('!R;V)L96TI"FEF("@A)'-T87)T7W!O<R!O<B`H
M)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PIM>2`E
M9&ES=%]C;60@/2!Q=R@*<"`@(&)L:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A
M<@IU("`@=6YI;G-T86QL7W!A<@IS("`@<VEG;E]P87(*=B`@('9E<FEF>5]P
M87(**3L*:68@*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*
M<VAI9G0@0$%21U8["B1%3E9[4$%27T%04%]2155317T@/2!S:&EF="!`05)'
M5CL*?0IE;'-E('L@(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T
M;U]I;F,["G=H:6QE("A`05)'5BD@>PHD05)'5ELP72`]?B`O7BTH6T%)34]"
M3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PII9B`H)#$@97$@)TDG*2!["G!U
M<V@@0&%D9%]T;U]I;F,L("0R.PI]"F5L<VEF("@D,2!E<2`G32<I('L*979A
M;"`B=7-E("0R(CL*?0IE;'-I9B`H)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A
M<E]A<F=S+"`D,CL*?0IE;'-I9B`H)#$@97$@)T\G*2!["B1O=70@/2`D,CL*
M?0IE;'-I9B`H)#$@97$@)V(G*2!["B1B=6YD;&4@/2`G<VET92<["GT*96QS
M:68@*"0Q(&5Q("=")RD@>PHD8G5N9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q
M(&5Q("=Q)RD@>PHD<75I970@/2`Q.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*
M;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92!Q<5M#86XG="!O<&5N(&QO
M9R!F:6QE("(D,B(Z("0A73L*?0IE;'-I9B`H)#$@97$@)U0G*2!["B1C86-H
M95]N86UE(#T@)#(["GT*<VAI9G0H0$%21U8I.PII9B`H;7D@)&-M9"`]("1D
M:7-T7V-M9'LD,7TI('L*9&5L971E("1%3E9[)U!!4E]414U0)WT["FEN:71?
M:6YC*"D["G)E<75I<F4@4$%2.CI$:7-T.PHF>R)005(Z.D1I<W0Z.B1C;60B
M?2@I('5N;&5S<R!`05)'5CL*)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O
M<B!`05)'5CL*97AI=#L*?0I]"G5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,[
M"GT*?0II9B`H)&]U="D@>PI["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@
M07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!.PI]"FUY("1P87(@
M/2!S:&EF="A`05)'5BD["FUY("1Z:7`["FEF("AD969I;F5D("1P87(I('L*
M;W!E;B!M>2`D9F@L("<\.G)A=R<L("1P87(@;W(@9&EE('%Q6T-A;B=T(&9I
M;F0@<&%R(&9I;&4@(B1P87(B.B`D(5T["F)L97-S*"1F:"P@)TE/.CI&:6QE
M)RD["B1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"`D>FEP+3YR96%D1G)O
M;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+
M*"D@*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN9R!Z:7`@87)C:&EV92`B)'!A
M<B)=.PI]"FUY("5M971A7W!A<B`](&1O('L*:68@*"1Z:7`@86YD(&UY("1M
M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*)&UE=&$@/7X@
M<R\N*EYP87(Z)"\O;7,["B1M971A(#U^(',O7EQ3+BHO+VUS.PHD;65T82`]
M?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["GT*?3L*:68@*&1E9FEN960@)'!A
M<BD@>PIO<&5N(&UY("1P:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N
M)W0@<F5A9"!P87(@9FEL92`B)'!A<B(Z("0A73L*;7D@)&)U9CL*<F5A9"`D
M<&@L("1B=68L(#0["F1I92!Q<5LB)'!A<B(@:7,@;F]T(&$@<&%R(&9I;&5=
M('5N;&5S<R`D8G5F(&5Q("102UI)4%]-04=)0SL*8VQO<V4@)'!H.PI]"D-R
M96%T95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T
M+`I)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?4D174B@I('P@
M24\Z.D9I;&4Z.D]?5%)53D,H*2P*,#<W-RP**2!O<B!D:64@<7%;0V%N)W0@
M8W)E871E(&9I;&4@(B1O=70B.B`D(5T["B1F:"T^8FEN;6]D92@I.PIS965K
M(%]&2"P@,"P@,#L*;7D@)&QO861E<CL*:68@*&1E9FEN960@)'-T87)T7V]F
M7T9)3$5?<V5C=&EO;BD@>PIR96%D(%]&2"P@)&QO861E<BP@)'-T87)T7V]F
M7T9)3$5?<V5C=&EO;CL*?2!E;'-E('L*;&]C86P@)"\@/2!U;F1E9CL*)&QO
M861E<B`](#Q?1D@^.PI]"FEF("@A)$5.5GM005)?5D520D%424U](&%N9"`D
M;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PIR97%U:7)E(%!!4CHZ1FEL
M=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<
M)&QO861E<BP@)#`I.PI]"B1F:"T^<')I;G0H)&QO861E<BD*;W(@9&EE('%Q
M6T5R<F]R('=R:71I;F<@;&]A9&5R('1O("(D;W5T(CH@)"%=.PII9B`H)&)U
M;F1L92D@>PIR97%U:7)E(%!!4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET
M7V1Y;F%L;V%D97(H*3L*:6YI=%]I;F,H*3L*<F5Q=6ER95]M;V1U;&5S*"D[
M"FUY($!I;F,@/2!G<F5P('L@(2]"4T1004XO('T*9W)E<"!["B@D8G5N9&QE
M(&YE("=S:71E)RD@;W(**"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB
M97AP?2!A;F0*)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*
M?2!`24Y#.PIS?"\K?"]\9RP@<WPO)'Q\(&9O<F5A8V@@0&EN8SL*;7D@)69I
M;&5S.PHD9FEL97-[)%]]*RL@9F]R($!$>6YA3&]A9&5R.CID;%]S:&%R961?
M;V)J96-T<RP@=F%L=65S("5)3D,["FUY("1L:6)?97AT(#T@)$-O;F9I9SHZ
M0V]N9FEG>VQI8E]E>'1].R`@("`@("`@(",@6%A8(&QI8E]E>'0@=G,@9&QE
M>'0@/PIM>2`E=W)I='1E;CL*9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@
M)69I;&5S*2!["FUY("@D9FEL92P@)&YA;64I.PII9B`H9&5F:6YE9"AM>2`D
M9F,@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1K97E]*2D@>PHH)&9I;&4L
M("1N86UE*2`]("@D:V5Y+"`D9F,I.PI]"F5L<V4@>PIF;W)E86-H(&UY("1D
M:7(@*$!I;F,I('L*:68@*"1K97D@/7X@;7Q>7%$D9&ER7$4O*"XJ*21\:2D@
M>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D,2D["FQA<W0["GT*:68@*"1K
M97D@/7X@;7Q>+VQO861E<B];7B]=*R\H+BHI)'PI('L*:68@*&UY("1R968@
M/2`D36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL92P@)&YA;64I(#T@*"1R968L
M("0Q*3L*;&%S=#L*?0II9B`H+68@(B1D:7(O)#$B*2!["B@D9FEL92P@)&YA
M;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL87-T.PI]"GT*?0I]"FYE>'0@=6YL
M97-S(&1E9FEN960@)&YA;64["FYE>'0@:68@)'=R:71T96Y[)&YA;65]*RL[
M"FYE>'0@:68@(7)E9B@D9FEL92D@86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E
M>'1<120O:3L*;W5T<RAS<')I;G1F*'%Q6U!A8VMI;F<@1DE,12`B)7,B+BXN
M72P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z("1F:6QE*2D["FUY("1C
M;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD8V]N=&5N="`]("1F:6QE+3Y[
M8G5F?3L*?0IE;'-E('L*;&]C86P@)"\@/2!U;F1E9CL*;W!E;B!M>2`D=&@L
M("<\.G)A=R<L("1F:6QE(&]R(&1I92!Q<5M#86XG="!R96%D("(D9FEL92(Z
M("0A73L*)&-O;G1E;G0@/2`\)'1H/CL*8VQO<V4@)'1H.PI005(Z.D9I;'1E
M<CHZ4&]D4W1R:7`M/F%P<&QY*%PD8V]N=&5N="P@(CQE;6)E9&1E9#XO)&YA
M;64B*0II9B`A)$5.5GM005)?5D520D%424U](&%N9"`D;F%M92`]?B`O7"XH
M/SIP;7QI>'QA;"DD+VD["E!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0M/FYE
M=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92P@)&YA;64I.PI]"B1F:"T^<')I
M;G0H(D9)3$4B+`IP86-K*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI+`IS<')I
M;G1F*"(E,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H)&-O
M;G1E;G0I+"`D;F%M92DL"G!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2P*
M)&-O;G1E;G0I"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG(&5M8F5D9&5D($9)
M3$4@=&\@(B1O=70B.B`D(5T["F]U=',H<7%;5W)I='1E;B!A<R`B)&YA;64B
M72D["GT*?0II9B`H)'II<"D@>PHD>FEP+3YW<FET951O1FEL94AA;F1L92@D
M9F@I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TL*;W(@9&EE('%Q6T5R<F]R('=R
M:71I;F<@>FEP('!A<G0@;V8@(B1O=70B73L*?0II9B`H)&UE=&%?<&%R>V-L
M96%N?2D@>PHD9F@M/G!R:6YT*")<,$-,14%.(BD["GT*96QS92!["FEF("@A
M9&5F:6YE9"`D8V%C:&5?;F%M92D@>PIM>2`D8W1X(#T@1&EG97-T.CI32$$M
M/FYE=R@Q*3L*<V5E:R`D9F@L(#`L(#`["B1C='@M/F%D9&9I;&4H)&9H*3L*
M<V5E:R`D9F@L(#`L(#(["B1C86-H95]N86UE(#T@)&-T>"T^:&5X9&EG97-T
M.PI]"B1C86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N86UE+"`P+"`D8V%C
M:&5?;F%M95]S:7IE.PHD8V%C:&5?;F%M92`N/2`B7#`B('@@*"1C86-H95]N
M86UE7W-I>F4@+2!L96YG=&@@)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT*"1C
M86-H95]N86UE+`HB7#!#04-(12(I.PI]"FUY("1O9F9S970@/2`D9F@M/G1E
M;&P@+2!L96YG=&@H)&QO861E<BD["B1F:"T^<')I;G0H<&%C:R@G3B<L("1O
M9F9S970I+`HD4$%27TU!1TE#*3L*)&9H+3YC;&]S92!O<B!D:64@<7%;17)R
M;W(@=W)I=&EN9R!T<F%I;&5R(&]F("(D;W5T(CH@)"%=.PIC:&UO9"`P-S4U
M+"`D;W5T.PIE>&ET.PI]"GL*;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?
M<&]S.PI?9FEX7W!R;V=N86UE*"D["G)E<75I<F4@4$%2.PI005(Z.DAE879Y
M.CI?:6YI=%]D>6YA;&]A9&5R*"D["GL*<F5Q=6ER92!&:6QE.CI&:6YD.PIR
M97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D9F@@/2!)3SHZ1FEL92T^;F5W
M.R`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(R!!<F-H:79E.CI::7`@
M;W!E<F%T97,@;VX@86X@24\Z.DAA;F1L90HD9F@M/F9D;W!E;BAF:6QE;F\H
M7T9(*2P@)W(G*2!O<B!D:64@<7%;9F1O<&5N*"D@9F%I;&5D.B`D(5T["D%R
M8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*"US(%]&2"D["FUY("1Z:7`@/2!!
M<F-H:79E.CI::7`M/FYE=SL**"1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D
M9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I*0IO<B!D
M:64@<7%;17)R;W(@<F5A9&EN9R!Z:7`@87)C:&EV92`B)'!R;V=N86UE(ET[
M"D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*#8T("H@,3`R-"D["G!U<V@@
M0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M
M97T@/2`D>FEP.PIO=71S*")%>'1R86-T:6YG('II<"XN+B(I.PII9B`H9&5F
M:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C('-H;W5L9"!B92!S970@870@=&AI
M<R!P;VEN="$*9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I
M('L*;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*;7D@)&UE;6)E<E]N
M86UE(#T@)&UE;6)E<BT^9FEL94YA;64["FYE>'0@=6YL97-S("1M96UB97)?
M;F%M92`]?B!M>PI>"B\_<VAL:6(O"B@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H
M;F%M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE(#T@)#$[
M"FUY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[4$%2
M7U1%35!]+"`D97AT<F%C=%]N86UE*3L*:68@*"UF("1D97-T7VYA;64@)B8@
M+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*;W5T<RAQ
M<5M3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E861Y(&5X
M:7-T<R!A="`B)&1E<W1?;F%M92)=*3L*?2!E;'-E('L*;W5T<RAQ<5M%>'1R
M86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(BXN+ETI.PHH
M)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I(#T]($%R
M8VAI=F4Z.EII<#HZ05I?3TLH*2D*;W(@9&EE('%Q6T5R<F]R(&5X=')A8W1I
M;F<@>FEP(&UE;6)E<B!T;R`B)&1E<W1?;F%M92)=.PIC:&UO9"@P-34U+"`D
M9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B.PI]"GT*?0I]"G5N;&5S<R`H
M)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@>PID:64@/#P@(BXB('5N;&5S
M<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@
M+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R;V=R86TN<&P@70HD,"!;("U"
M?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN"B1%3E9[4$%27U!23T=.04U%
M?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H0$%21U8I.PI]"G-U8B!#<F5A
M=&50871H('L*;7D@*"1N86UE*2`]($!?.PIR97%U:7)E($9I;&4Z.D)A<V5N
M86UE.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E
M;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG*2D["G)E<75I<F4@1FEL
M93HZ4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H*"1P871H*2!U;FQE<W,H+64@
M)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@97)R;W(*?0IS=6(@<F5Q=6ER
M95]M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E<75I<F4@1'EN84QO861E<CL*
M<F5Q=6ER92!I;G1E9V5R.PIR97%U:7)E('-T<FEC=#L*<F5Q=6ER92!W87)N
M:6YG<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E($-A<G`["G)E<75I<F4@0V%R
M<#HZ2&5A=GD["G)E<75I<F4@17)R;F\["G)E<75I<F4@17AP;W)T97(Z.DAE
M879Y.PIR97%U:7)E($5X<&]R=&5R.PIR97%U:7)E($9C;G1L.PIR97%U:7)E
M($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ4W!E8SL*<F5Q=6ER92!84TQO
M861E<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I<F4@24\Z.DAA;F1L93L*<F5Q
M=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*<F5Q=6ER
M92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["G)E<75I<F4@
M4$%2.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@4$%2.CI$:7-T.PIR
M97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*<F5Q=6ER92!005(Z.D9I
M;'1E<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E(&%T=')I8G5T97,["F5V86P@
M>R!R97%U:7)E($-W9"!].PIE=F%L('L@<F5Q=6ER92!7:6XS,B!].PIE=F%L
M('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*979A;"![(')E<75I<F4@07)C
M:&EV93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@>R!R97%U:7)E(%1I93HZ2&%S
M:#HZ3F%M961#87!T=7)E('T["F5V86P@>R!R97%U:7)E(%!E<FQ)3SL@<F5Q
M=6ER92!097)L24\Z.G-C86QA<B!].PIE=F%L('L@<F5Q=6ER92!U=&8X('T[
M"GT*<W5B(%]S971?<&%R7W1E;7`@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]4
M14U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO*2!["B1P87)?=&5M
M<"`]("0Q.PIR971U<FX["GT*9F]R96%C:"!M>2`D<&%T:"`H"BAM87`@)$5.
M5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!414U01$E2(%1%35`@5$U0
M("DI+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D**2!["FYE>'0@=6YL97-S(&1E
M9FEN960@)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D<&%T:#L*;7D@)'5S
M97)N86UE.PIM>2`D<'=U:60["F5V86P@>R@D<'=U:60I(#T@9V5T<'=U:60H
M)#XI(&EF(&1E9FEN960@)#X[?3L*:68@*"!D969I;F5D*"97:6XS,CHZ3&]G
M:6Y.86UE*2`I('L*)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA;64["GT*
M96QS:68@*&1E9FEN960@)'!W=6ED*2!["B1U<V5R;F%M92`]("1P=W5I9#L*
M?0IE;'-E('L*)'5S97)N86UE(#T@)$5.5GM54T523D%-17T@?'P@)$5.5GM5
M4T52?2!\?"`G4UE35$5-)SL*?0IM>2`D<W1M<&1I<B`]("(D<&%T:"1S>7-[
M7V1E;&EM?7!A<BTB+G5N<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D
M<W1M<&1I<BP@,#<U-3L*;7D@)&-A8VAE7V1I<CL*:68@*"1%3E9[4$%27T-,
M14%.?2D@>PHD8V%C:&5?9&ER(#T@(G1E;7`M)"0B.PI]"F5L<V4@>PIO<&5N
M(&UY("1F:"P@(CPZ<F%W(BP@)'!R;V=N86UE(&]R(&1I92!Q<5M#86XG="!R
M96%D("(D<')O9VYA;64B.B`D(5T["FEF("@H;7D@)&UA9VEC7W!O<R`](&9I
M;F1?<&%R7VUA9VEC*"1F:"DI(#X](#`I('L*<V5E:R`D9F@L("1M86=I8U]P
M;W,*+2`D1DE,15]O9F9S971?<VEZ90HM(&QE;F=T:"@B7#!#04-(12(I+"`P
M.PIM>2`D8G5F.PIR96%D("1F:"P@)&)U9BP@;&5N9W1H*")<,$-!0TA%(BD[
M"FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS965K("1F:"P@)&UA9VEC7W!O
M<PHM("1&24Q%7V]F9G-E=%]S:7IE"BT@;&5N9W1H*")<,$-!0TA%(BD*+2`D
M8V%C:&5?;F%M95]S:7IE+"`P.PIR96%D("1F:"P@)&)U9BP@)&-A8VAE7VYA
M;65?<VEZ93L*)&)U9B`]?B!S+UPP+R]G.PHD8V%C:&5?9&ER(#T@(F-A8VAE
M+21B=68B.PI]"GT*8VQO<V4@)&9H.PI]"FEF("@A)&-A8VAE7V1I<BD@>PHD
M8V%C:&5?9&ER(#T@(G1E;7`M)"0B.PHD14Y6>U!!4E]#3$5!3GT@/2`Q.PI]
M"B1S=&UP9&ER("X]("(D<WES>U]D96QI;7TD8V%C:&5?9&ER(CL*;6MD:7(@
M)'-T;7!D:7(L(#`W-34["B1%3E9[4$%27U1%35!](#T@)'-T;7!D:7(["FQA
M<W0["GT*)'!A<E]T96UP(#T@)#$@:68@)$5.5GM005)?5$5-4'T@86YD("1%
M3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0IS=6(@7W-A=F5?87,@>PIM>2`H
M)&YA;64L("1C;VYT96YT<RP@)&UO9&4I(#T@0%\["FUY("1F=6QL;F%M92`]
M("(D<&%R7W1E;7`O)&YA;64B.PIU;FQE<W,@*"UE("1F=6QL;F%M92D@>PIM
M>2`D=&5M<&YA;64@/2`B)&9U;&QN86UE+B0D(CL*;7D@)&9H.PHH;W!E;B`D
M9F@L("<^.G)A=R<L("1T96UP;F%M92D*)B8@*'!R:6YT("1F:"`D8V]N=&5N
M=',I"B8F("AC;&]S92`D9F@I"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG("(D
M=&5M<&YA;64B.B`D(5T["F-H;6]D("1M;V1E+"`D=&5M<&YA;64@:68@9&5F
M:6YE9"`D;6]D93L*<F5N86UE*"1T96UP;F%M92P@)&9U;&QN86UE*2!O<B!U
M;FQI;FLH)'1E;7!N86UE*3L*?0IR971U<FX@)&9U;&QN86UE.PI]"G-U8B!?
M<V5T7W!R;V=N86UE('L*:68@*&1E9FEN960@)$5.5GM005)?4%)/1TY!345]
M(&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2!["B1P<F]G;F%M
M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@)#`["FEF("@D14Y6>U!!4E]414U0
M?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@
M>PHD<')O9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N
M86UE+"`D<WES>U]D96QI;7TI("L@,2D["GT*:68@*"$D14Y6>U!!4E]04D]'
M3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI(#X](#`I
M('L*:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@>PIR971U<FX@
M:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N86UE)'-Y<WM?97AE?2(I('L*
M)'!R;V=N86UE("X]("1S>7-[7V5X97T["G)E='5R;CL*?0I]"F9O<F5A8V@@
M;7D@)&1I<B`H<W!L:70@+UQ1)'-Y<WMP871H7W-E<'U<12\L("1%3E9[4$%4
M2'TI('L*;F5X="!I9B!E>&ES=',@)$5.5GM005)?5$5-4'T@86YD("1D:7(@
M97$@)$5.5GM005)?5$5-4'T["B1D:7(@/7X@<R]<421S>7-[7V1E;&EM?5Q%
M)"\O.PHH*"1P<F]G;F%M92`]("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE
M)'-Y<WM?97AE?2(I+"!L87-T*0II9B`M<R`B)&1I<B1S>7-[7V1E;&EM?21P
M<F]G;F%M921S>7-[7V5X97TB.PHH*"1P<F]G;F%M92`]("(D9&ER)'-Y<WM?
M9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L
M:6U])'!R;V=N86UE(CL*?0I]"G-U8B!?9FEX7W!R;V=N86UE('L*)#`@/2`D
M<')O9VYA;64@?'P]("1%3E9[4$%27U!23T=.04U%?3L*:68@*&EN9&5X*"1P
M<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`\(#`I('L*)'!R;V=N86UE(#T@(BXD
M<WES>U]D96QI;7TD<')O9VYA;64B.PI]"FUY("1P=V0@/2`H9&5F:6YE9"`F
M0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H*0HZ("@H9&5F:6YE9"`F5VEN
M,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D["F-H;VUP
M*"1P=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421S>7-[7V1E;&EM
M?5Q%*2\D<'=D)'-Y<WM?9&5L:6U]+SL*)$5.5GM005)?4%)/1TY!345](#T@
M)'!R;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?96YV('L*:68@*"`D14Y6>U!!
M4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PIR971U<FX["GT@96QS92!["B1%
M3E9[4$%27TE.251)04Q)6D5$?2`](#(["GT*9F]R("AQ=R@@4U!!5TY%1"!4
M14U0($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%("D@*2!["F1E;&5T92`D
M14Y6>R)005)?)%\B?3L*?0IF;W(@*'%W+R!435!$25(@5$5-4"!#3$5!3B!$
M14)51R`O*2!["B1%3E9[(E!!4E\D7R)](#T@)$5.5GLB4$%27T=,3T)!3%\D
M7R)](&EF(&5X:7-T<R`D14Y6>R)005)?1TQ/0D%,7R1?(GT["GT*:68@*"1%
M3E9[4$%27U1%35!]*2!["F1E;&5T92`D14Y6>U!!4E]#3$5!3GT["GT*?0IS
M=6(@;W5T<R!["G)E='5R;B!I9B`D<75I970["FEF("@D;&]G9F@I('L*<')I
M;G0@)&QO9V9H(")`7UQN(CL*?0IE;'-E('L*<')I;G0@(D!?7&XB.PI]"GT*
M<W5B(&EN:71?:6YC('L*<F5Q=6ER92!#;VYF:6<["G!U<V@@0$E.0RP@9W)E
M<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H"F%R8VAL
M:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X<"!S:71E;&EB97AP"G9E;F1O
M<F%R8VAE>'`@=F5N9&]R;&EB97AP"BD["GT*<&%C:V%G92!M86EN.PIR97%U
M:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^
M:6UP;W)T*$!P87)?87)G<RD["F1I92!Q<5MP87(N<&PZ($-A;B=T(&]P96X@
M<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E
M8W1O<GE<;ET*=6YL97-S("UE("1P<F]G;F%M93L*9&\@)'!R;V=N86UE.PI#
M3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I
M.PID:64@)$`@:68@)$`["GT["B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*?0I#
M3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?7"@H
M7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF("0Z.E]?15)23U(["C$["E]?
M14Y$7U\*`%5315(``%5315).04U%``!414U01$E2`%1-4``O=&UP`````'!E
M<FQX<VDN8P``0T%#2$4```````````$;`SL```#L````'/__@?````8D__^$
M<````0C__X5X```!./__G!@```%X__^<Z````<C__YUX```!^/__GN@```(T
M__^?8````G#__Z!@```"L/__HO@```+P__^C,````P3__Z0P```#2/__I#@`
M``-<__^FH````YS__Z;8```#R/__J#````00__^MP```!$3__ZY````$=/__
MKK@```2@__^PH```!.3__[#0```%!/__L<````54__^XR```!:3__[L````%
MX/__N]````9D__^\0```!HC__[XP```&S/__OS````<(`````````!0`````
M`7I2``%X#@$;#`^@`0<.`````!0````<__^#8````$(``````````````!0`
M`````7I2``%X#@$;#`^@`0```````#P````<__^$.```%IH`1H8.APV(#(D+
MB@J+"8P(C0>.!H\%1@[0!P,6?@K/SLW,R\K)R,?&#J`!0@L```````!,````
M7/__FI@```#.`$R&#H<-B`R)"XH*BPF,"(T'C@:/!48.P`("C`K/SLW,R\K)
MR,?&#J`!0@M<"L_.S<S+RLG(Q\8.H`%""P```````"P```"L__^;&````)``
M1HH*BPF,"(T'C@:/!48.V`,"?`K/SLW,R\H.H`%""P```#@```#<__^;>```
M`6H`1H8.APV(#(D+B@J+"8P(C0>.!H\%1@[@`W8*S\[-S,O*R<C'Q@Z@`4(+
M`````#@```$8__^<K````'0`3(8.APV(#(D+B@J+"8P(C0>.!H\%1@[(`@)@
MS\[-S,O*R<C'Q@Z@`0```````#P```%4__^<Z````0``1H<-B`R)"XH*BPF,
M"(T'C@:/!48.H"%,#L@B`IH*S\[-S,O*R<C'#J`!0@L````````\```!E/__
MG:@```*6`$:&#H<-B`R)"XH*BPF,"(T'C@:/!48.X`(#`4X*S\[-S,O*R<C'
MQ@Z@`4(+````````$````=3__Z``````.`````````!````!Z/__H"0```#^
M`$:&#H<-B`R)"XH*BPF,"(T'C@:/!48.H"%,#J!!3`[80@+*"L_.S<S+RLG(
MQ\8.H`%""P```!````(L__^@X`````8`````````/````D#__Z#4```":`!&
MA@Z'#8@,B0N*"HL)C`B-!XX&CP5&#J`A3`[P(P)Z"L_.S<S+RLG(Q\8.H`%"
M"P```"@```*`__^B_````#8`2HL)C`B-!XX&CP5*#L`"7,_.S<S+#J`!````
M````1````JS__Z,(```!5`!&B0N*"HL)C`B-!XX&CP5&#J`A3`[((@+F"L_.
MS<S+RLD.H`%""UP*S\[-S,O*R0Z@`48+````````,````O3__Z08```%C`!&
MB@J+"8P(C0>.!H\%1@[0`@,%2@K/SLW,R\H.H`%&"P```````"P```,H__^I
M=````(``3(L)C`B-!XX&CP5&#M`"`EX*S\[-S,L.H`%""P```````"@```-8
M__^IQ````'@`7(8.APV(#(D+B@J+"8P(C0>.!H\%1@[H`@``````0````X3_
M_ZH0```!Z`!&B`R)"XH*BPF,"(T'C@:/!48,#J"!!%@-#T8.T(($`P&2"L_.
MS<S+RLG(#J`!0@L````````<```#R/__J[0````L`$:.!H\%1@[``E[/S@Z@
M`0```$P```/H__^KQ````/``1H8.APV(#(D+B@J+"8P(C0>.!H\%1@[@`@)4
M"L_.S<S+RLG(Q\8.H`%&"P)^"L_.S<S+RLG(Q\8.H`%&"P``````3```!#C_
M_ZQD```'`@!*A@Z'#8@,B0N*"HL)C`B-!XX&CP5&#O@$`P*R"L_.S<S+RLG(
MQ\8.H`%""P,"\@K/SLW,R\K)R,?&#J`!1@L````X```$B/__LQP```(V`$:'
M#8@,B0N*"HL)C`B-!XX&CP5&#M`"`P'$"L_.S<S+RLG(QPZ@`4(+``````!`
M```$Q/__M1@```#0`$:)"XH*BPF,"(T'C@:/!48.T`("7@K/SLW,R\K)#J`!
M0@L"6`K/SLW,R\K)#J`!1@L``````#P```4(__][Q````H``1H8.APV(#(D+
MB@J+"8P(C0>.!H\%1@[H`@,!P`K/SLW,R\K)R,?&#J`!0@L````````@```%
M2/__M60```!L`$J.!H\%1@[``@):S\X.H`$```````!````%;/__M;````'J
M`$:&#H<-B`R)"XH*BPF,"(T'C@:/!4H.T`),F!:9%0,!?@K/SLW,R\K)R,?&
MV=@.H`%""P```#@```6P__^W7````/P`1H@,B0N*"HL)C`B-!XX&CP5<#L`"
M`J@*S\[-S,O*R<@.H`%&"P```````````!````7L__^X(`````P`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````*0`````````HN```````
M```!`````````MH``````````0````````+E`````````!T````````$80``
M```````,````````'F``````````#0```````&+0`````````!D```````"[
MJ``````````;``````````@`````````&@```````+NP`````````!P`````
M````"``````````$`````````I``````;__^]0````````>@``````````4`
M```````1.``````````&````````"(``````````"@````````25````````
M``L`````````&``````````5`````````````````````P```````+W8````
M``````(````````%$``````````4``````````<`````````%P```````!E0
M``````````<````````6^``````````(`````````E@`````````"0``````
M```8`````````!X`````````"`````!O___[``````@```$`````;____@``
M`````!:(`````&____\``````````0````!O___P````````%<X`````;___
M^0`````````.````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````"[N``````````````````````````````>S@```````![N````````
M'PX````````?+@```````!].````````'VX````````?C@```````!^N````
M````'\X````````?[@```````"`.````````("X````````@3@```````"!N
M````````((X````````@K@```````"#.````````(.X````````A#@``````
M`"$N````````(4X````````A;@```````"&.````````(:X````````AS@``
M`````"'N````````(@X````````B+@```````").````````(FX````````B
MC@```````"*N````````(LX````````B[@```````",.````````(RX`````
M```C3@```````"-N````````(XX````````CK@```````"/.````````(^X`
M```````D#@```````"0N````````)$X````````D;@```````"2.````````
M)*X````````DS@```````"3N````````)0X````````E+@```````"5.````
M````)6X`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````)8```````````````````,`("E!!4BYP;0H`````````````
M`````*-P````````8UP``````````````````&/\````````9`````````"C
M9````````&-B````````HVP``````````````````*-4````````HUH`````
M`````````````&7D1T-#.B`H4U5312!,:6YU>"D@,30N,BXQ(#(P,C4P,C(P
M(%MR979I<VEO;B`Y9F9E8V1E,3(Q868X.#-B-C!B8F4V,&0P,#0R-3`S-F)C
M.#<S,#0X70``+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N04))+71A9P`N;F]T
M92YG;G4N8G5I;&0M:60`+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N9VYU
M+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E;&$N9'EN`"YR96QA+G!L=``N
M:6YI=``N=&5X=``N9FEN:0`N<F]D871A`"YE:%]F<F%M95]H9'(`+F5H7V9R
M86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YD>6YA;6EC`"YG;W0`+F1A
M=&$`+F)S<P`N8V]M;65N=```````````````````````````````````````
M````````````````````````````````````````````````````"P````$`
M`````````@````````(X`````````C@`````````#P``````````````````
M``$``````````````!,````'``````````(````````"2`````````)(````
M`````"`````````````````````$```````````````A````!P`````````"
M`````````F@````````":``````````D````````````````````!```````
M````````.`````4``````````@````````*0`````````I`````````%$```
M``8```````````````@`````````"````#1O___V``````````(````````'
MH`````````>@`````````-P````&```````````````(```````````````^
M````"P`````````"````````"(`````````(@`````````BX````!P````(`
M````````"``````````8````1@````,``````````@```````!$X````````
M$3@````````$E0````````````````````$``````````````$YO____````
M``````(````````5S@```````!7.`````````+H````&```````````````"
M``````````(```!;;____@`````````"````````%H@````````6B```````
M``!P````!P````$`````````"```````````````:@````0``````````@``
M`````!;X````````%O@````````"6`````8```````````````@`````````
M&````'0````$`````````$(````````94````````!E0````````!1`````&
M````%@`````````(`````````!@```!^`````0`````````&````````'F``
M```````>8``````````^````````````````````!```````````````>0``
M``$`````````!@```````!Z@````````'J`````````&X```````````````
M``````0`````````(````(0````!``````````8````````E@````````"6`
M````````/5`````````````````````(``````````````"*`````0``````
M```&````````8M````````!BT``````````J````````````````````!```
M````````````D`````$``````````@```````&,`````````8P````````!`
MD`````````````````````@``````````````)@````!``````````(`````
M``"CD````````*.0`````````.P````````````````````$````````````
M``"F`````0`````````"````````I(````````"D@`````````8P````````
M````````````"```````````````L`````X``````````P```````+NH````
M````JZ@`````````"`````````````````````@`````````"````+P````/
M``````````,```````"[L````````*NP``````````@`````````````````
M```(``````````@```#(````!@`````````#````````N[@```````"KN```
M``````(@````!P``````````````"``````````0````T0````$`````````
M`P```````+W8````````K=@````````"*`````````````````````@`````
M````"````-8````!``````````,```````#``````````+```````````(@`
M```````````````````(``````````````#<````"``````````#````````
MP(@```````"PB``````````H````````````````````"```````````````
MX0````$`````````,```````````````````L(@`````````5@``````````
M``````````$``````````0````$````#````````````````````````````
C`+#>`````````.H````````````````````!````````````
